# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DCMUNPACK_METADATA = Metadata(
    id="01d871981fcfe7211d8f4250bbd352a2a097e2e7.boutiques",
    name="dcmunpack",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class DcmunpackOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dcmunpack(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def dcmunpack(
    src: str,
    targ: str | None = None,
    run: str | None = None,
    auto_runseq: str | None = None,
    keep_scouts: bool = False,
    scanonly: str | None = None,
    one_per_dir: bool = False,
    ext: str | None = None,
    pre: str | None = None,
    pat: str | None = None,
    no_infodump: bool = False,
    generic: bool = False,
    copy_only: bool = False,
    no_convert: bool = False,
    force_update: bool = False,
    max_: bool = False,
    base: bool = False,
    key_string: str | None = None,
    index_out: str | None = None,
    index_in: str | None = None,
    it_dicom: bool = False,
    no_exit_on_error: bool = False,
    run_skip: str | None = None,
    no_rescale_dicom: bool = False,
    rescale_dicom: bool = False,
    no_dwi: bool = False,
    iid: list[float] | None = None,
    ijd: list[float] | None = None,
    ikd: list[float] | None = None,
    extra_info: bool = False,
    first_dicom: bool = False,
    no_dcm2niix: bool = False,
    phase: bool = False,
    fips: str | None = None,
    fips_run: str | None = None,
    xml_only: bool = False,
    log: str | None = None,
    debug: bool = False,
    runner: Runner | None = None,
) -> DcmunpackOutputs:
    """
    Sorts and converts a directory of DICOM files (Siemens, GE, Philips) into an
    output hierarchy with nifti (nii), mgh, mgz, or analyze output formats.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        src: Dicom source directory. You can specify more than one.
        targ: Output directory. Do not need to include when just getting\
            information about what is in the directory.
        run: Specify unpacking rules for a given run (series). Eg, "-run 3 bold\
            nii f.nii".
        auto_runseq: Save all scans in the targetdir as runo.seqname.format.
        keep_scouts: Unpack series with 'scout' or 'setter' in the name.
        scanonly: Only scan the directory and put result in file.
        one_per_dir: Assume that there is only one dicom series in each subdir.
        ext: Input extension (eg, dcm).
        pre: Input prefix (i.e., input file name init string).
        pat: Input pattern (i.e., string that occurs in the middle of file\
            name).
        no_infodump: Do not create the fname-infodump.dat file.
        generic: Do not use FSFAST hierarchy.
        copy_only: Only copy dicom files to output directory (implies\
            -no-convert).
        no_convert: Do not convert to output format.
        force_update: Convert even if output is newer than the input dicom.
        max_: Print out max in given dicom file.
        base: Report filename without path.
        key_string: Put keystring before each run line (good for searching).
        index_out: Save index of files to index.out.dat (for re-use).
        index_in: Read index of files (can make things much faster on 2nd run).
        it_dicom: Add -it dicom to mri_convert cmd line.
        no_exit_on_error: Continue to unpack data even if there is an error in\
            conversion.
        run_skip: Skip a given run (good when using -auto-runseq).
        no_rescale_dicom: Turn off DICOM rescaling based on tags (0028,1052)\
            (0028,1053).
        rescale_dicom: Turn DICOM rescaling on.
        no_dwi: Turn off trying to read DWI parameters.
        iid: Set -iid to mri_convert.
        ijd: Set -ijd to mri_convert.
        ikd: Set -ikd to mri_convert.
        extra_info: Add session info to each line of the info file (pat, date,\
            man, scan, field, serno).
        first_dicom: Copy first dicom file into output folder.
        no_dcm2niix: Turn off dcm2niix conversion.
        phase: Add the string _phase to volumes that are phase images based on\
            ImageType.
        fips: Fips parameters: project, site, birnid, visit.
        fips_run: Fips-run parameters: run paradigm.
        xml_only: For fips, only create xml file, do not convert to output.
        log: Log output to a file.
        debug: Enable debug mode.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DcmunpackOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DCMUNPACK_METADATA)
    cargs = []
    cargs.append("dcmunpack")
    cargs.extend([
        "-src",
        src
    ])
    if targ is not None:
        cargs.extend([
            "-targ",
            targ
        ])
    if run is not None:
        cargs.extend([
            "-run",
            run
        ])
    if auto_runseq is not None:
        cargs.extend([
            "-auto-runseq",
            auto_runseq
        ])
    if keep_scouts:
        cargs.append("-keep-scouts")
    if scanonly is not None:
        cargs.extend([
            "-scanonly",
            scanonly
        ])
    if one_per_dir:
        cargs.append("-one-per-dir")
    if ext is not None:
        cargs.extend([
            "-ext",
            ext
        ])
    if pre is not None:
        cargs.extend([
            "-pre",
            pre
        ])
    if pat is not None:
        cargs.extend([
            "-pat",
            pat
        ])
    if no_infodump:
        cargs.append("-no-infodump")
    if generic:
        cargs.append("-generic")
    if copy_only:
        cargs.append("-copy-only")
    if no_convert:
        cargs.append("-no-convert")
    if force_update:
        cargs.append("-force-update")
    if max_:
        cargs.append("-max")
    if base:
        cargs.append("-base")
    if key_string is not None:
        cargs.extend([
            "-key",
            key_string
        ])
    if index_out is not None:
        cargs.extend([
            "-index-out",
            index_out
        ])
    if index_in is not None:
        cargs.extend([
            "-index-in",
            index_in
        ])
    if it_dicom:
        cargs.append("-itdicom")
    if no_exit_on_error:
        cargs.append("-no-exit-on-error")
    if run_skip is not None:
        cargs.extend([
            "-run-skip",
            run_skip
        ])
    if no_rescale_dicom:
        cargs.append("-no-rescale-dicom")
    if rescale_dicom:
        cargs.append("-rescale-dicom")
    if no_dwi:
        cargs.append("-no-dwi")
    if iid is not None:
        cargs.extend([
            "-iid",
            *map(str, iid)
        ])
    if ijd is not None:
        cargs.extend([
            "-ijd",
            *map(str, ijd)
        ])
    if ikd is not None:
        cargs.extend([
            "-ikd",
            *map(str, ikd)
        ])
    if extra_info:
        cargs.append("-extra-info")
    if first_dicom:
        cargs.append("-first-dicom")
    if no_dcm2niix:
        cargs.append("-no-dcm2niix")
    if phase:
        cargs.append("-phase")
    if fips is not None:
        cargs.extend([
            "-fips",
            fips
        ])
    if fips_run is not None:
        cargs.extend([
            "-fips-run",
            fips_run
        ])
    if xml_only:
        cargs.append("-xml-only")
    if log is not None:
        cargs.extend([
            "-log",
            log
        ])
    if debug:
        cargs.append("-debug")
    ret = DcmunpackOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DCMUNPACK_METADATA",
    "DcmunpackOutputs",
    "dcmunpack",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LONG_STATS_COMBINE_METADATA = Metadata(
    id="44c43a96c18b3f3b72a80aed68ec585e7b861c9d.boutiques",
    name="long_stats_combine",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class LongStatsCombineOutputs(typing.NamedTuple):
    """
    Output object returned when calling `long_stats_combine(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_qdec_file: OutputPathType
    """Output long qdec table"""
    output_stacked_stats_file: OutputPathType | None
    """Stacked stats table for all subjects, all time points"""


def long_stats_combine(
    qdec: InputPathType,
    stats: str,
    measure: str,
    subject_dir: str,
    output_qdec: str,
    output_stats: str | None = None,
    input_stats: InputPathType | None = None,
    cross_sectional: bool = False,
    runner: Runner | None = None,
) -> LongStatsCombineOutputs:
    """
    Adds columns from stats into longitudinal qdec table, using longitudinally
    processed results.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        qdec: QDEC table file specifying the subjects and time points. File has\
            first columns: fsid fsid-base.
        stats: The stats file, e.g. aseg.stats or lh.aparc.stats.
        measure: The stats measure (e.g. volume, thickness, mean, std).
        subject_dir: Full path to FreeSurfer subjects directory.
        output_qdec: File name of output long qdec table.
        output_stats: File name to output stacked stats table (all subjects,\
            all time points).
        input_stats: File name of stacked stats table (same order as qdec),\
            instead of using --stats and --meas.
        cross_sectional: Use cross sectional results (for testing only).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LongStatsCombineOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LONG_STATS_COMBINE_METADATA)
    cargs = []
    cargs.append("long_stats_combine")
    cargs.extend([
        "--qdec",
        execution.input_file(qdec)
    ])
    cargs.extend([
        "--stats",
        stats
    ])
    cargs.extend([
        "--meas",
        measure
    ])
    cargs.extend([
        "--sd",
        subject_dir
    ])
    cargs.append("--out")
    cargs.extend([
        "--outqdec",
        output_qdec
    ])
    if output_stats is not None:
        cargs.extend([
            "--outstats",
            output_stats
        ])
    if input_stats is not None:
        cargs.extend([
            "--instats",
            execution.input_file(input_stats)
        ])
    if cross_sectional:
        cargs.append("--cross")
    ret = LongStatsCombineOutputs(
        root=execution.output_file("."),
        output_qdec_file=execution.output_file(output_qdec),
        output_stacked_stats_file=execution.output_file(output_stats) if (output_stats is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LONG_STATS_COMBINE_METADATA",
    "LongStatsCombineOutputs",
    "long_stats_combine",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MERGESEG_METADATA = Metadata(
    id="8df8bb8db74182788b29b00177c93fd3d1402bd4.boutiques",
    name="mergeseg",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MergesegOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mergeseg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_seg: OutputPathType
    """Output merged segmentation result."""


def mergeseg(
    src_seg: InputPathType,
    merge_seg: InputPathType,
    out_seg: InputPathType,
    segid: float | None = None,
    segid_only: float | None = None,
    segid_erode: float | None = None,
    ctab: InputPathType | None = None,
    runner: Runner | None = None,
) -> MergesegOutputs:
    """
    Merges one segmentation into another, replacing the source voxels with those
    from the merge segmentation where non-zero.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        src_seg: Source segmentation image file.
        merge_seg: Merge segmentation volume file.
        out_seg: Output merged segmentation.
        segid: Segmentation index (optional). If specified, all the voxels in\
            the merge seg will be set to segindex.
        segid_only: Only take segindex from merge and use it for merging.
        segid_erode: Erode seg-only segindex before merge. Specify the number\
            of erosion iterations.
        ctab: Color table to embed in the output segmentation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MergesegOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MERGESEG_METADATA)
    cargs = []
    cargs.append("mergeseg")
    cargs.append(execution.input_file(src_seg))
    cargs.append(execution.input_file(merge_seg))
    cargs.extend([
        "--o",
        execution.input_file(out_seg)
    ])
    if segid is not None:
        cargs.extend([
            "--segid",
            str(segid)
        ])
    if segid_only is not None:
        cargs.extend([
            "--segid-only",
            str(segid_only)
        ])
    if segid_erode is not None:
        cargs.extend([
            "--segid-erode",
            str(segid_erode)
        ])
    if ctab is not None:
        cargs.extend([
            "--ctab",
            execution.input_file(ctab)
        ])
    ret = MergesegOutputs(
        root=execution.output_file("."),
        output_seg=execution.output_file(pathlib.Path(out_seg).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MERGESEG_METADATA",
    "MergesegOutputs",
    "mergeseg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RCBF_PREP_METADATA = Metadata(
    id="1a26630009bc7f6431b9c45507dba269ec5c416e.boutiques",
    name="rcbf-prep",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class RcbfPrepOutputs(typing.NamedTuple):
    """
    Output object returned when calling `rcbf_prep(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    hemisphere_rcbf: OutputPathType
    """Registered and resampled rCBF volume for both hemispheres."""
    mni305_rcbf: OutputPathType
    """rCBF volume resampled to MNI305 space."""
    roi_stats: OutputPathType
    """Stats file summarizing the ROIs."""


def rcbf_prep(
    outdir: str,
    rcbfvol: InputPathType,
    subject: str | None = None,
    roitab: InputPathType | None = None,
    register: InputPathType | None = None,
    template: InputPathType | None = None,
    runner: Runner | None = None,
) -> RcbfPrepOutputs:
    """
    Performs integration of rCBF as produced by Siemens scanners with FreeSurfer
    analysis in preparation for group analysis.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        outdir: Output directory where results will be stored.
        rcbfvol: Input rCBF volume to be registered to the FreeSurfer\
            anatomical.
        subject: Subject identifier for FreeSurfer anatomical registration.
        roitab: ROI table specifying which ROIs will be summarized, e.g.,\
            FreeSurferColorLUT.txt.
        register: Registration data file instead of a subject.
        template: Template file used instead of rCBF itself.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RcbfPrepOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RCBF_PREP_METADATA)
    cargs = []
    cargs.append("rcbf-prep")
    cargs.extend([
        "--o",
        outdir
    ])
    cargs.extend([
        "--rcbf",
        execution.input_file(rcbfvol)
    ])
    if subject is not None:
        cargs.extend([
            "--s",
            subject
        ])
    if roitab is not None:
        cargs.extend([
            "--roitab",
            execution.input_file(roitab)
        ])
    if register is not None:
        cargs.extend([
            "--reg",
            execution.input_file(register)
        ])
    if template is not None:
        cargs.extend([
            "--t",
            execution.input_file(template)
        ])
    ret = RcbfPrepOutputs(
        root=execution.output_file("."),
        hemisphere_rcbf=execution.output_file(outdir + "/?h.rcbf.mgh"),
        mni305_rcbf=execution.output_file(outdir + "/rcbf.mni305.nii"),
        roi_stats=execution.output_file(outdir + "/roi.dat"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RCBF_PREP_METADATA",
    "RcbfPrepOutputs",
    "rcbf_prep",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TAL_QC_AZS_METADATA = Metadata(
    id="886563f0c6afbd7ecc04616fab1fcccc741bff0c.boutiques",
    name="tal_QC_AZS",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class TalQcAzsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tal_qc_azs(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def tal_qc_azs(
    logfile: InputPathType,
    runner: Runner | None = None,
) -> TalQcAzsOutputs:
    """
    A tool that processes a logfile.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        logfile: Input logfile for processing.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TalQcAzsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TAL_QC_AZS_METADATA)
    cargs = []
    cargs.append("tal_QC_AZS")
    cargs.append(execution.input_file(logfile))
    ret = TalQcAzsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TAL_QC_AZS_METADATA",
    "TalQcAzsOutputs",
    "tal_qc_azs",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SEGMENT_SUBJECT_NOTAL2_METADATA = Metadata(
    id="6303522667922b1bee80bfcf692f9907c22c58f7.boutiques",
    name="segment_subject_notal2",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class SegmentSubjectNotal2Outputs(typing.NamedTuple):
    """
    Output object returned when calling `segment_subject_notal2(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dir: OutputPathType
    """Output directory containing the segmented results"""


def segment_subject_notal2(
    license_file: InputPathType,
    runner: Runner | None = None,
) -> SegmentSubjectNotal2Outputs:
    """
    FreeSurfer tool for segmenting subject data using notal2 algorithm.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        license_file: FreeSurfer license file is required to run the\
            application. Obtain from\
            http://surfer.nmr.mgh.harvard.edu/registration.html.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SegmentSubjectNotal2Outputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SEGMENT_SUBJECT_NOTAL2_METADATA)
    cargs = []
    cargs.append("segment_subject_notal2")
    cargs.extend([
        "--fs-license-file",
        execution.input_file(license_file)
    ])
    ret = SegmentSubjectNotal2Outputs(
        root=execution.output_file("."),
        output_dir=execution.output_file("segmented_output"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SEGMENT_SUBJECT_NOTAL2_METADATA",
    "SegmentSubjectNotal2Outputs",
    "segment_subject_notal2",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_DCT_ALIGN_BINARY_METADATA = Metadata(
    id="2faa7e8342fe3be51e2e7f03e5e9f5ad22147ad8.boutiques",
    name="mri_dct_align_binary",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriDctAlignBinaryOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_dct_align_binary(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_transformation_file: OutputPathType
    """The resulting transformation from the alignment"""


def mri_dct_align_binary(
    source_image: InputPathType,
    destination_image: InputPathType,
    output_transformation: str,
    runner: Runner | None = None,
) -> MriDctAlignBinaryOutputs:
    """
    A binary tool for aligning MRI images using DCT.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        source_image: Source image for alignment.
        destination_image: Destination image for alignment.
        output_transformation: Output transformation file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriDctAlignBinaryOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_DCT_ALIGN_BINARY_METADATA)
    cargs = []
    cargs.append("mri_dct_align_binary")
    cargs.append(execution.input_file(source_image))
    cargs.append(execution.input_file(destination_image))
    cargs.append(output_transformation)
    ret = MriDctAlignBinaryOutputs(
        root=execution.output_file("."),
        output_transformation_file=execution.output_file(output_transformation),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_DCT_ALIGN_BINARY_METADATA",
    "MriDctAlignBinaryOutputs",
    "mri_dct_align_binary",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_COR2LABEL_METADATA = Metadata(
    id="af9da52f4b4f506776cedf44bf8558f6771cc4d7.boutiques",
    name="mri_cor2label",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriCor2labelOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_cor2label(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_label_file: OutputPathType
    """Generated label file."""
    output_volume_file: OutputPathType | None
    """Written volume label if specified."""


def mri_cor2label(
    input_file: InputPathType,
    label_id: float,
    label_file: str,
    threshold: float | None = None,
    volume_file: str | None = None,
    surface_overlay: list[str] | None = None,
    surface_path: str | None = None,
    optimize: list[str] | None = None,
    remove_holes_islands: bool = False,
    dilate: float | None = None,
    erode: float | None = None,
    help_: bool = False,
    runner: Runner | None = None,
) -> MriCor2labelOutputs:
    """
    Converts values in a volume or surface overlay to a label. Designed to convert
    parcellation volumes stored in mri format.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input volume or surface overlay file.
        label_id: Value to match in the input data.
        label_file: Name of the output label file.
        threshold: Threshold the input to make label, e.g., input values must\
            be greater than the threshold.
        volume_file: Write the label volume to a file.
        surface_overlay: Interpret input as a surface overlay, specifying\
            subject, hemisphere, and surface.
        surface_path: Specify surface path rather than subject/hemisphere.
        optimize: Treat input as a probability map and optimize thresholding.
        remove_holes_islands: Remove holes in label and islands (only valid\
            with --surf).
        dilate: Dilate label with specified number of dilations (only valid\
            with --surf).
        erode: Erode label with specified number of erosions (only valid with\
            --surf).
        help_: Display help information.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriCor2labelOutputs`).
    """
    if surface_overlay is not None and (len(surface_overlay) != 3): 
        raise ValueError(f"Length of 'surface_overlay' must be 3 but was {len(surface_overlay)}")
    if optimize is not None and (len(optimize) != 3): 
        raise ValueError(f"Length of 'optimize' must be 3 but was {len(optimize)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_COR2LABEL_METADATA)
    cargs = []
    cargs.append("mri_cor2label")
    cargs.extend([
        "-i",
        execution.input_file(input_file)
    ])
    cargs.extend([
        "-id",
        str(label_id)
    ])
    cargs.extend([
        "-l",
        label_file
    ])
    if threshold is not None:
        cargs.extend([
            "--thresh",
            str(threshold)
        ])
    if volume_file is not None:
        cargs.extend([
            "--v",
            volume_file
        ])
    if surface_overlay is not None:
        cargs.extend([
            "--surf",
            *surface_overlay
        ])
    if surface_path is not None:
        cargs.extend([
            "--surf-path",
            surface_path
        ])
    if optimize is not None:
        cargs.extend([
            "--opt",
            *optimize
        ])
    if remove_holes_islands:
        cargs.append("--remove-holes-islands")
    if dilate is not None:
        cargs.extend([
            "--dilate",
            str(dilate)
        ])
    if erode is not None:
        cargs.extend([
            "--erode",
            str(erode)
        ])
    if help_:
        cargs.append("--help")
    ret = MriCor2labelOutputs(
        root=execution.output_file("."),
        output_label_file=execution.output_file(label_file),
        output_volume_file=execution.output_file(volume_file) if (volume_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_COR2LABEL_METADATA",
    "MriCor2labelOutputs",
    "mri_cor2label",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__SCALE_VOLUME_METADATA = Metadata(
    id="4000996fdc6423040b991fc320209305f64cb474.boutiques",
    name="@ScaleVolume",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VScaleVolumeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__scale_volume(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output scaled dataset"""


def v__scale_volume(
    input_dset: InputPathType,
    prefix: str,
    val_clip: list[float] | None = None,
    perc_clip: list[float] | None = None,
    scale_by_mean: bool = False,
    scale_by_median: bool = False,
    norm: bool = False,
    mask: InputPathType | None = None,
    runner: Runner | None = None,
) -> VScaleVolumeOutputs:
    """
    A tool to scale the volume of datasets.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_dset: Dataset to scale.
        prefix: Prefix of output.
        val_clip: Min and Max of output dataset. Default V0 = 0 and V1 = 255.
        perc_clip: Set lowest P0 percentile to Min and highest P1 percentile to\
            Max. Default P0 = 2 and P1 = 98.
        scale_by_mean: Divide each sub-brick by mean of non-zero voxels.
        scale_by_median: Divide each sub-brick by median of non-zero voxels.
        norm: For each time series T, Tnorm = (T - mean(T)) / stdev(T).
        mask: Restrict to non-zero values of given mask dataset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VScaleVolumeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__SCALE_VOLUME_METADATA)
    cargs = []
    cargs.append("@ScaleVolume")
    cargs.append(execution.input_file(input_dset))
    cargs.append(prefix)
    if val_clip is not None:
        cargs.extend([
            "-val_clip",
            *map(str, val_clip)
        ])
    if perc_clip is not None:
        cargs.extend([
            "-perc_clip",
            *map(str, perc_clip)
        ])
    if scale_by_mean:
        cargs.append("-scale_by_mean")
    if scale_by_median:
        cargs.append("-scale_by_median")
    if norm:
        cargs.append("-norm")
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    ret = VScaleVolumeOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file("<-prefix PREFIX>_scaled"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VScaleVolumeOutputs",
    "V__SCALE_VOLUME_METADATA",
    "v__scale_volume",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MAP_ICOSAHEDRON_METADATA = Metadata(
    id="29dbfdf370b411c5e1a730bd832837169913b924.boutiques",
    name="MapIcosahedron",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class MapIcosahedronOutputs(typing.NamedTuple):
    """
    Output object returned when calling `map_icosahedron(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def map_icosahedron(
    spec_file: InputPathType,
    rec_depth: float | None = None,
    lin_depth: float | None = None,
    morph_surf: str | None = None,
    num_it: float | None = None,
    prefix: str | None = None,
    nn_dset: str | None = None,
    dset: str | None = None,
    fix_cut_surfaces: bool = False,
    verbosity: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> MapIcosahedronOutputs:
    """
    Creates new versions of original-mesh surfaces using the mesh of an icosahedron.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        spec_file: Spec file containing original-mesh surfaces.
        rec_depth: Recursive (binary) tessellation depth for icosahedron\
            (default: 3).
        lin_depth: Number of edge divides for linear icosahedron tessellation.
        morph_surf: Specifies the morphSurf surface.
        num_it: Number of smoothing iterations.
        prefix: Prefix for output files (default: 'std.').
        nn_dset: Map DSET onto the new mesh using Nearest Neighbor\
            interpolation.
        dset: Map DSET onto the new mesh using barycentric interpolation.
        fix_cut_surfaces: Check and fix standard-mesh surfaces with cuts for\
            cross-cut connections.
        verbosity: Enable verbose output.
        help_: Display the help text.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MapIcosahedronOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MAP_ICOSAHEDRON_METADATA)
    cargs = []
    cargs.append("MapIcosahedron")
    cargs.append(execution.input_file(spec_file))
    if rec_depth is not None:
        cargs.extend([
            "-rd",
            str(rec_depth)
        ])
    if lin_depth is not None:
        cargs.extend([
            "-ld",
            str(lin_depth)
        ])
    if morph_surf is not None:
        cargs.extend([
            "-morph",
            morph_surf
        ])
    if num_it is not None:
        cargs.extend([
            "-it",
            str(num_it)
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if nn_dset is not None:
        cargs.extend([
            "-NN_dset_map",
            nn_dset
        ])
    if dset is not None:
        cargs.extend([
            "-dset_map",
            dset
        ])
    if fix_cut_surfaces:
        cargs.append("-fix_cut_surfaces")
    if verbosity:
        cargs.append("-verb")
    if help_:
        cargs.append("-help")
    ret = MapIcosahedronOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MAP_ICOSAHEDRON_METADATA",
    "MapIcosahedronOutputs",
    "map_icosahedron",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1DDOT_METADATA = Metadata(
    id="89e3bea294b27fb22b4f6d2f28db83dbf8daea66.boutiques",
    name="1ddot",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1ddotOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1ddot(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    stdout_output: OutputPathType
    """Output correlation or covariance matrix printed to stdout."""


def v_1ddot(
    input_files: list[InputPathType],
    one_flag: bool = False,
    dem_flag: bool = False,
    cov_flag: bool = False,
    inn_flag: bool = False,
    rank_flag: bool = False,
    terse_flag: bool = False,
    okzero_flag: bool = False,
    runner: Runner | None = None,
) -> V1ddotOutputs:
    """
    Computes the correlation matrix of the input 1D files and their inverse
    correlation matrix.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_files: Input 1D files.
        one_flag: Make 1st vector be all 1's.
        dem_flag: Remove mean from all vectors (conflicts with '-one').
        cov_flag: Compute with covariance matrix instead of correlation.
        inn_flag: Compute with inner product matrix instead.
        rank_flag: Compute Spearman rank correlation instead (also implies\
            '-terse').
        terse_flag: Output only the correlation or covariance matrix without\
            any garnish.
        okzero_flag: Do not quit if a vector is all zeros. The correlation\
            matrix will have 0 where NaNs ought to go.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1ddotOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1DDOT_METADATA)
    cargs = []
    cargs.append("1ddot")
    if one_flag:
        cargs.append("-one")
    if dem_flag:
        cargs.append("-dem")
    if cov_flag:
        cargs.append("-cov")
    if inn_flag:
        cargs.append("-inn")
    if rank_flag:
        cargs.append("-rank")
    if terse_flag:
        cargs.append("-terse")
    if okzero_flag:
        cargs.append("-okzero")
    cargs.extend([execution.input_file(f) for f in input_files])
    cargs.append(">")
    cargs.append("stdout.txt")
    ret = V1ddotOutputs(
        root=execution.output_file("."),
        stdout_output=execution.output_file("stdout.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1ddotOutputs",
    "V_1DDOT_METADATA",
    "v_1ddot",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSL_REGFILT_METADATA = Metadata(
    id="c358956cca1d2a0a95737c27fdb8da975b6c0db6.boutiques",
    name="fsl_regfilt",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FslRegfiltOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsl_regfilt(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    filtered_data: OutputPathType
    """Filtered data output"""
    preprocessed_data: OutputPathType | None
    """Pre-processed data output"""
    mixing_matrix: OutputPathType | None
    """New mixing matrix output"""
    vnscales: OutputPathType | None
    """Variance normalisation scaling factors output"""


def fsl_regfilt(
    infile: InputPathType,
    designfile: InputPathType,
    outfile: str,
    maskfile: InputPathType | None = None,
    filter_: str | None = None,
    freq_filter_flag: bool = False,
    freq_ic_flag: bool = False,
    freq_ic_smooth: float | None = None,
    fthresh: float | None = 0.15,
    fthresh2: float | None = 0.02,
    vn_flag: bool = False,
    verbose_flag: bool = False,
    aggressive_flag: bool = False,
    help_flag: bool = False,
    out_data: str | None = None,
    out_mix: str | None = None,
    out_vnscales: str | None = None,
    runner: Runner | None = None,
) -> FslRegfiltOutputs:
    """
    Data de-noising by regressing out part of a design matrix using simple OLS
    regression on 4D images.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        infile: Input file name (4D image).
        designfile: File name of the matrix with time courses (e.g. GLM design\
            or MELODIC mixing matrix).
        outfile: Output file name for the filtered data.
        maskfile: Mask image file name.
        filter_: Filter out part of the regression model, e.g., -f "1,2,3".
        freq_filter_flag: Filter out components based on high vs. low frequency\
            content.
        freq_ic_flag: Switch off IC Z-stats filtering as part of frequency\
            filtering.
        freq_ic_smooth: Smoothing width for IC Z-stats filtering as part of\
            frequency filtering.
        fthresh: Frequency threshold ratio; default: 0.15.
        fthresh2: Frequency filter score threshold; default: 0.02.
        vn_flag: Perform variance-normalisation on data.
        verbose_flag: Switch on diagnostic messages.
        aggressive_flag: Switch on aggressive filtering (full instead of\
            partial regression).
        help_flag: Display help text.
        out_data: Output file name for pre-processed data (prior to denoising).
        out_mix: Output file name for new mixing matrix.
        out_vnscales: Output file name for scaling factors from variance\
            normalisation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslRegfiltOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSL_REGFILT_METADATA)
    cargs = []
    cargs.append("fsl_regfilt")
    cargs.extend([
        "-i",
        execution.input_file(infile)
    ])
    cargs.extend([
        "-d",
        execution.input_file(designfile)
    ])
    cargs.extend([
        "-o",
        outfile
    ])
    if maskfile is not None:
        cargs.extend([
            "-m",
            execution.input_file(maskfile)
        ])
    if filter_ is not None:
        cargs.extend([
            "-f",
            filter_
        ])
    if freq_filter_flag:
        cargs.append("-F")
    if freq_ic_flag:
        cargs.append("--freq_ic")
    if freq_ic_smooth is not None:
        cargs.extend([
            "--freq_ic_smooth",
            str(freq_ic_smooth)
        ])
    if fthresh is not None:
        cargs.extend([
            "--fthresh",
            str(fthresh)
        ])
    if fthresh2 is not None:
        cargs.extend([
            "--fthresh2",
            str(fthresh2)
        ])
    if vn_flag:
        cargs.append("--vn")
    if verbose_flag:
        cargs.append("-v")
    if aggressive_flag:
        cargs.append("-a")
    if help_flag:
        cargs.append("-h")
    if out_data is not None:
        cargs.extend([
            "--out_data",
            out_data
        ])
    if out_mix is not None:
        cargs.extend([
            "--out_mix",
            out_mix
        ])
    if out_vnscales is not None:
        cargs.extend([
            "--out_vnscales",
            out_vnscales
        ])
    ret = FslRegfiltOutputs(
        root=execution.output_file("."),
        filtered_data=execution.output_file(outfile + ".nii.gz"),
        preprocessed_data=execution.output_file(out_data + ".nii.gz") if (out_data is not None) else None,
        mixing_matrix=execution.output_file(out_mix + ".nii.gz") if (out_mix is not None) else None,
        vnscales=execution.output_file(out_vnscales + ".nii.gz") if (out_vnscales is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSL_REGFILT_METADATA",
    "FslRegfiltOutputs",
    "fsl_regfilt",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_CLUST_COUNT_METADATA = Metadata(
    id="98fcc8c7fba23c3985c9517555b10b2b9741fa23.boutiques",
    name="3dClustCount",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dClustCountOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_clust_count(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    clustcount_niml: OutputPathType | None
    """Summed results file in NIML format."""
    clustcount_1_d: OutputPathType | None
    """Summed results file in 1D format (when '-final' is used)."""
    final_clustcount_niml: OutputPathType | None
    """Summed results file in NIML format (when '-final' is used)."""


def v_3d_clust_count(
    datasets: list[InputPathType],
    prefix: str | None = None,
    final: bool = False,
    quiet: bool = False,
    runner: Runner | None = None,
) -> V3dClustCountOutputs:
    """
    This program takes as input 1 or more datasets, thresholds them at various
    levels, and counts up the number of clusters of various sizes.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        datasets: Input datasets to be processed.
        prefix: Prefix of the filename into which results will be summed.\
            Actual filename will be 'sss.clustcount.niml'. If this file already\
            exists, results from the current run will be summed into the existing\
            results and the file then re-written.
        final: Output results in a format similar to 3dClustSim -- as 1D and\
            NIML formatted files with probabilities of various cluster sizes. This\
            option can be used without any input datasets to create final output\
            files from saved '.clustcount.niml' output file from earlier runs.
        quiet: Suppresses progress reports and other informational messages.\
            Should be placed first in the command line to quiet most messages.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dClustCountOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_CLUST_COUNT_METADATA)
    cargs = []
    cargs.append("3dClustCount")
    cargs.extend([execution.input_file(f) for f in datasets])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if final:
        cargs.append("-final")
    if quiet:
        cargs.append("-quiet")
    ret = V3dClustCountOutputs(
        root=execution.output_file("."),
        clustcount_niml=execution.output_file(prefix + ".clustcount.niml") if (prefix is not None) else None,
        clustcount_1_d=execution.output_file(prefix + ".1D") if (prefix is not None) else None,
        final_clustcount_niml=execution.output_file(prefix + ".niml") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dClustCountOutputs",
    "V_3D_CLUST_COUNT_METADATA",
    "v_3d_clust_count",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3_DROIMAKER_METADATA = Metadata(
    id="52994e672a5f137f27dbb8bbd59f66cee7093ffe.boutiques",
    name="3DROIMaker",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3DroimakerOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3_droimaker(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    gm_map: OutputPathType
    """GM map of ROIs based on value- and volume-thresholding, corresponding to
    gray matter regions of activation."""
    gmi_map: OutputPathType
    """Map of inflated GM ROIs based on GM map, with ROIs inflated either by
    user-design or WM skeleton."""


def v_3_droimaker(
    inset: InputPathType,
    thresh: float,
    prefix: str,
    refset: InputPathType | None = None,
    volthr: float | None = None,
    only_conn_top: float | None = None,
    inflate: float | None = None,
    trim_off_wm: bool = False,
    wm_skel: InputPathType | None = None,
    skel_thr: float | None = None,
    skel_stop: bool = False,
    skel_stop_strict: bool = False,
    csf_skel: InputPathType | None = None,
    mask: InputPathType | None = None,
    neigh_upto_vert: bool = False,
    nifti: bool = False,
    preinfl_inset: InputPathType | None = None,
    preinfl_inflate: float | None = None,
    dump_no_labtab: bool = False,
    runner: Runner | None = None,
) -> V3DroimakerOutputs:
    """
    Create a labelled set of ROIs from input data, useful in combining functional
    and tractographic/structural data.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        inset: 3D volume(s) of values, especially functionally-derived\
            quantities like correlation values or ICA Z-scores.
        thresh: Threshold for values in INSET, used to create ROI islands from\
            the 3D volume's sea of values.
        prefix: Prefix of output name, with output files being: PREFIX_GM* and\
            PREFIX_GMI*.
        refset: 3D (or multi-subbrick) volume containing integer values with\
            which to label specific GM ROIs after thresholding.
        volthr: Minimum size a cluster of voxels must have in order to remain a\
            GM ROI after thresholding. Can reduce 'noisy' clusters.
        only_conn_top: Select N max contiguous voxels in a region starting from\
            peak voxel and expanding.
        inflate: Number of voxels to pad each found ROI in order to turn GM\
            ROIs into inflated (GMI) ROIs.
        trim_off_wm: Trim the INSET to exclude voxels in WM by excluding those\
            which overlap an input WM skeleton.
        wm_skel: 3D volume containing info of WM, as might be defined from an\
            FA map or anatomical segmentation.
        skel_thr: Threshold value for WM skeleton if it is not a mask.
        skel_stop: Stop inflation at locations which are already on WM\
            skeleton.
        skel_stop_strict: Do not allow any inflation into the skel-region.
        csf_skel: 3D volume containing info of CSF. Info must be a binary mask\
            already.
        mask: Mask within which to apply threshold. Useful if the MINTHR is a\
            negative value.
        neigh_upto_vert: Define neighbors loosely so that voxels can be grouped\
            into the same ROI if they share at least one vertex.
        nifti: Switch to output *.nii.gz GM and GMI files.
        preinfl_inset: Start with a WM ROI, inflate it to find the nearest GM,\
            then expand that GM and subtract away the WM+CSF parts.
        preinfl_inflate: Number of voxels for initial inflation of PSET.
        dump_no_labtab: Switch for turning off labeltable attachment to the\
            output GM and GMI files.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3DroimakerOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3_DROIMAKER_METADATA)
    cargs = []
    cargs.append("3dROIMaker")
    cargs.append(execution.input_file(inset))
    cargs.extend([
        "-thresh",
        str(thresh)
    ])
    cargs.extend([
        "-prefix",
        prefix
    ])
    if refset is not None:
        cargs.extend([
            "-refset",
            execution.input_file(refset)
        ])
    if volthr is not None:
        cargs.extend([
            "-volthr",
            str(volthr)
        ])
    if only_conn_top is not None:
        cargs.extend([
            "-only_conn_top",
            str(only_conn_top)
        ])
    if inflate is not None:
        cargs.extend([
            "-inflate",
            str(inflate)
        ])
    if trim_off_wm:
        cargs.append("-trim_off_wm")
    if wm_skel is not None:
        cargs.extend([
            "-wm_skel",
            execution.input_file(wm_skel)
        ])
    if skel_thr is not None:
        cargs.extend([
            "-skel_thr",
            str(skel_thr)
        ])
    if skel_stop:
        cargs.append("-skel_stop")
    if skel_stop_strict:
        cargs.append("-skel_stop_strict")
    if csf_skel is not None:
        cargs.extend([
            "-csf_skel",
            execution.input_file(csf_skel)
        ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if neigh_upto_vert:
        cargs.append("-neigh_upto_vert")
    if nifti:
        cargs.append("-nifti")
    if preinfl_inset is not None:
        cargs.extend([
            "-preinfl_inset",
            execution.input_file(preinfl_inset)
        ])
    if preinfl_inflate is not None:
        cargs.extend([
            "-preinfl_inflate",
            str(preinfl_inflate)
        ])
    if dump_no_labtab:
        cargs.append("-dump_no_labtab")
    ret = V3DroimakerOutputs(
        root=execution.output_file("."),
        gm_map=execution.output_file(prefix + "_GM+orig.*.HEAD"),
        gmi_map=execution.output_file(prefix + "_GMI+orig.*.HEAD"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3DroimakerOutputs",
    "V_3_DROIMAKER_METADATA",
    "v_3_droimaker",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__DJUNCT_ANONYMIZE_METADATA = Metadata(
    id="b39c604a1cb220842f1bff1090f5403b2eb497f0.boutiques",
    name="@djunct_anonymize",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VDjunctAnonymizeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__djunct_anonymize(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__djunct_anonymize(
    input_: InputPathType,
    add_note: str | None = None,
    copy_to: InputPathType | None = None,
    overwrite: bool = False,
    runner: Runner | None = None,
) -> VDjunctAnonymizeOutputs:
    """
    Helper program to anonymize files.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_: Input dataset.
        add_note: Add a note to the history after anonymizing.
        copy_to: Copy the input to a new file, which is then anonymized.
        overwrite: Overwrite the existing file if using -copy_to.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VDjunctAnonymizeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__DJUNCT_ANONYMIZE_METADATA)
    cargs = []
    cargs.append("@djunct_anonymize")
    cargs.append(execution.input_file(input_))
    if add_note is not None:
        cargs.extend([
            "-add_note",
            add_note
        ])
    if copy_to is not None:
        cargs.extend([
            "-copy_to",
            execution.input_file(copy_to)
        ])
    if overwrite:
        cargs.append("-overwrite")
    ret = VDjunctAnonymizeOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VDjunctAnonymizeOutputs",
    "V__DJUNCT_ANONYMIZE_METADATA",
    "v__djunct_anonymize",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_MVM_METADATA = Metadata(
    id="f66a98f269fed22500c7f8aa62cd43c5d51fda61.boutiques",
    name="3dMVM",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dMvmOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_mvm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile_head: OutputPathType
    """Output HEAD file in AFNI format"""
    outfile_brik: OutputPathType
    """Output BRIK file in AFNI format"""


def v_3d_mvm(
    prefix: str,
    bs_vars: str,
    data_table: str,
    dbg_args: str | None = None,
    jobs: int | None = None,
    mask: InputPathType | None = None,
    ws_vars: str | None = None,
    q_vars: str | None = None,
    q_var_centers: str | None = None,
    num_glt: int | None = None,
    glt_label: str | None = None,
    glt_code: str | None = None,
    num_glf: int | None = None,
    glf_label: str | None = None,
    glf_code: str | None = None,
    runner: Runner | None = None,
) -> V3dMvmOutputs:
    """
    AFNI Group Analysis Program with Multi-Variate Modeling Approach.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        prefix: Output file name prefix.
        bs_vars: Formula for between-subjects variables.
        data_table: Data table for analysis.
        dbg_args: Enable R to save parameters in a file for debugging.
        jobs: Number of jobs for parallel processing.
        mask: Only process voxels inside this mask.
        ws_vars: Formula for within-subjects variables.
        q_vars: Comma-separated list of quantitative variables (covariates).
        q_var_centers: Comma-separated centering values for quantitative\
            variables.
        num_glt: Number of general linear t-tests (GLTs).
        glt_label: Label for each general linear t-test (GLT).
        glt_code: Coding for each general linear t-test (GLT).
        num_glf: Number of general linear F-tests (GLFs).
        glf_label: Label for each general linear F-test (GLF).
        glf_code: Coding for each general linear F-test (GLF).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dMvmOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_MVM_METADATA)
    cargs = []
    cargs.append("3dMVM")
    if dbg_args is not None:
        cargs.append(dbg_args)
    cargs.extend([
        "-prefix",
        prefix
    ])
    if jobs is not None:
        cargs.extend([
            "-jobs",
            str(jobs)
        ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    cargs.extend([
        "-bsVars",
        bs_vars
    ])
    if ws_vars is not None:
        cargs.extend([
            "-wsVars",
            ws_vars
        ])
    if q_vars is not None:
        cargs.extend([
            "-qVars",
            q_vars
        ])
    if q_var_centers is not None:
        cargs.extend([
            "-qVarCenters",
            q_var_centers
        ])
    if num_glt is not None:
        cargs.extend([
            "-num_glt",
            str(num_glt)
        ])
    if glt_label is not None:
        cargs.extend([
            "-gltLabel",
            glt_label
        ])
    if glt_code is not None:
        cargs.extend([
            "-gltCode",
            glt_code
        ])
    if num_glf is not None:
        cargs.extend([
            "-num_glf",
            str(num_glf)
        ])
    if glf_label is not None:
        cargs.extend([
            "-glfLabel",
            glf_label
        ])
    if glf_code is not None:
        cargs.extend([
            "-glfCode",
            glf_code
        ])
    cargs.extend([
        "-dataTable",
        data_table
    ])
    ret = V3dMvmOutputs(
        root=execution.output_file("."),
        outfile_head=execution.output_file(prefix + "+tlrc.HEAD"),
        outfile_brik=execution.output_file(prefix + "+tlrc.BRIK"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dMvmOutputs",
    "V_3D_MVM_METADATA",
    "v_3d_mvm",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_ISC_METADATA = Metadata(
    id="d937806e40a345507430d710b195292450cd9998.boutiques",
    name="3dISC",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dIscOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_isc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    isc_output: OutputPathType
    """Main output ISC file"""
    tstat_output: OutputPathType
    """T-statistic of ISC"""


def v_3d_isc(
    outfile_prefix: str,
    model_structure: str,
    data_table: str,
    num_jobs: float | None = None,
    mask_file: InputPathType | None = None,
    qvar_centers: str | None = None,
    quantitative_vars: str | None = None,
    fisher_transform: bool = False,
    io_functions: typing.Literal["AFNI", "R"] | None = None,
    runner: Runner | None = None,
) -> V3dIscOutputs:
    """
    Program for Voxelwise Inter-Subject Correlation (ISC) Analysis using linear
    mixed-effects modeling.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        outfile_prefix: Output file name. For AFNI format, provide prefix only,\
            with no view+suffix needed.
        model_structure: Specify the model structure for all the variables. The\
            expression FORMULA with more than one variable has to be surrounded\
            within quotes.
        data_table: List the data structure with a header as the first line.\
            Has to occur last in the script.
        num_jobs: Specify the number of jobs to run concurrently. Choose 1 for\
            a single-processor computer.
        mask_file: Process voxels inside this mask only. Default is no masking.
        qvar_centers: Specify centering values for quantitative variables\
            identified under -qVars. Multiple centers are separated by commas\
            without spaces and should be within quotes.
        quantitative_vars: Identify quantitative variables (or covariates). The\
            list should be comma-separated and within quotes.
        fisher_transform: Perform Fisher transformation on the response\
            variable (input files) if it is a correlation value.
        io_functions: Use AFNI's C io functions (default) or R's io functions.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dIscOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_ISC_METADATA)
    cargs = []
    cargs.append("3dISC")
    cargs.extend([
        "-prefix",
        outfile_prefix
    ])
    if num_jobs is not None:
        cargs.extend([
            "-jobs",
            str(num_jobs)
        ])
    if mask_file is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask_file)
        ])
    cargs.extend([
        "-model",
        model_structure
    ])
    if qvar_centers is not None:
        cargs.extend([
            "-qVarCenters",
            qvar_centers
        ])
    if quantitative_vars is not None:
        cargs.extend([
            "-qVars",
            quantitative_vars
        ])
    if fisher_transform:
        cargs.append("-r2z")
    if io_functions is not None:
        cargs.extend([
            "-cio",
            io_functions
        ])
    cargs.extend([
        "-dataTable",
        data_table
    ])
    ret = V3dIscOutputs(
        root=execution.output_file("."),
        isc_output=execution.output_file(outfile_prefix + "_ISC.nii"),
        tstat_output=execution.output_file(outfile_prefix + "_tstat.nii"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dIscOutputs",
    "V_3D_ISC_METADATA",
    "v_3d_isc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_REPOSITION_SURFACE_METADATA = Metadata(
    id="41b35ee93a58eac699b67d7d488cbcc2df5c677b.boutiques",
    name="mris_reposition_surface",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisRepositionSurfaceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_reposition_surface(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_surface: OutputPathType
    """Output surface file"""


def mris_reposition_surface(
    surf: InputPathType,
    volume: InputPathType,
    points: InputPathType,
    output: str,
    size: float | None = 1,
    sigma: float | None = 2.0,
    iterations: float | None = 1,
    runner: Runner | None = None,
) -> MrisRepositionSurfaceOutputs:
    """
    Reposition a surface based on the given control points (in JSON format).
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        surf: Input surface.
        volume: Input volume.
        points: Input points.
        output: Output surface filename.
        size: Size parameter for repositioning. Default is 1.
        sigma: Sigma. Default is 2.0.
        iterations: Number of iterations. Default is 1.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisRepositionSurfaceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_REPOSITION_SURFACE_METADATA)
    cargs = []
    cargs.append("mris_reposition_surface")
    cargs.extend([
        "-s",
        execution.input_file(surf)
    ])
    cargs.extend([
        "-v",
        execution.input_file(volume)
    ])
    cargs.extend([
        "-p",
        execution.input_file(points)
    ])
    cargs.extend([
        "-o",
        output
    ])
    if size is not None:
        cargs.extend([
            "-z",
            str(size)
        ])
    if sigma is not None:
        cargs.extend([
            "-g",
            str(sigma)
        ])
    if iterations is not None:
        cargs.extend([
            "-i",
            str(iterations)
        ])
    ret = MrisRepositionSurfaceOutputs(
        root=execution.output_file("."),
        output_surface=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_REPOSITION_SURFACE_METADATA",
    "MrisRepositionSurfaceOutputs",
    "mris_reposition_surface",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSFIRST_FSL_METADATA = Metadata(
    id="fe4368d67f0bf44514ba8d3556dd0dd0df276d60.boutiques",
    name="fsfirst.fsl",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FsfirstFslOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsfirst_fsl(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fsfirst_fsl(
    runner: Runner | None = None,
) -> FsfirstFslOutputs:
    """
    The tool intended for FSL's FIRST module, responsible for model-based
    segmentation and registration of subcortical structures.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FsfirstFslOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSFIRST_FSL_METADATA)
    cargs = []
    cargs.append("fsfirst.fsl")
    ret = FsfirstFslOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSFIRST_FSL_METADATA",
    "FsfirstFslOutputs",
    "fsfirst_fsl",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VOL2SYMSURF_METADATA = Metadata(
    id="22e164f84127031ad07cd425f37456f6e49f209f.boutiques",
    name="vol2symsurf",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Vol2symsurfOutputs(typing.NamedTuple):
    """
    Output object returned when calling `vol2symsurf(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_lh: OutputPathType | None
    """Output for left hemisphere"""
    output_rh: OutputPathType | None
    """Output for right hemisphere"""
    output_lh_rh_difference: OutputPathType | None
    """Output for left-right hemisphere difference"""
    output_li_difference: OutputPathType | None
    """Output for laterality index"""


def vol2symsurf(
    registration_file: InputPathType,
    input_volume: InputPathType,
    fwhm: float,
    output_stem: str | None = "instem.fsaverage_sym.smFWHM.lh.hemi",
    regheader: str | None = None,
    projection_fraction: float | None = 0.5,
    no_diff: bool = False,
    laterality_index: bool = False,
    runner: Runner | None = None,
) -> Vol2symsurfOutputs:
    """
    A tool that samples a volume onto the surface of the left-right symmetric
    subject (fsaverage_sym).
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        registration_file: Registration file.
        input_volume: Input volume in NIfTI format.
        fwhm: Full width at half maximum for surface smoothing.
        output_stem: Output stem.
        regheader: Subject for regheader.
        projection_fraction: Projection fraction.
        no_diff: Do not compute left-right hemisphere difference.
        laterality_index: Compute laterality index instead of simple difference.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Vol2symsurfOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOL2SYMSURF_METADATA)
    cargs = []
    cargs.append("vol2symsurf")
    cargs.extend([
        "--reg",
        execution.input_file(registration_file)
    ])
    cargs.extend([
        "--i",
        execution.input_file(input_volume)
    ])
    cargs.extend([
        "--fwhm",
        str(fwhm)
    ])
    if output_stem is not None:
        cargs.extend([
            "--o",
            output_stem
        ])
    if regheader is not None:
        cargs.extend([
            "--regheader",
            regheader
        ])
    if projection_fraction is not None:
        cargs.extend([
            "--projfrac",
            str(projection_fraction)
        ])
    if no_diff:
        cargs.append("--no-diff")
    if laterality_index:
        cargs.append("--li")
    ret = Vol2symsurfOutputs(
        root=execution.output_file("."),
        output_lh=execution.output_file(output_stem + ".lh.nii") if (output_stem is not None) else None,
        output_rh=execution.output_file(output_stem + ".rh.nii") if (output_stem is not None) else None,
        output_lh_rh_difference=execution.output_file(output_stem + ".lh-rh.nii") if (output_stem is not None) else None,
        output_li_difference=execution.output_file(output_stem + ".li.lh-rh.nii") if (output_stem is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VOL2SYMSURF_METADATA",
    "Vol2symsurfOutputs",
    "vol2symsurf",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANTS_APPLY_TRANSFORMS_METADATA = Metadata(
    id="8209354b35fca6222f53525ec72fc9f4429a7c4a.boutiques",
    name="antsApplyTransforms",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class AntsApplyTransformsWarpedOutputOutputs(typing.NamedTuple):
    """
    Output object returned when calling `AntsApplyTransformsWarpedOutput(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image_outfile: OutputPathType
    """Warped image."""


@dataclasses.dataclass
class AntsApplyTransformsWarpedOutput:
    """
    Output the warped image.
    """
    warped_output_file_name: str
    """Output file name."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append(self.warped_output_file_name)
        return cargs
    
    def outputs(
        self,
        execution: Execution,
    ) -> AntsApplyTransformsWarpedOutputOutputs:
        """
        Collect output file paths.
        
        Args:
            execution: The execution object.
        Returns:
            NamedTuple of outputs (described in `AntsApplyTransformsWarpedOutputOutputs`).
        """
        ret = AntsApplyTransformsWarpedOutputOutputs(
            root=execution.output_file("."),
            output_image_outfile=execution.output_file(self.warped_output_file_name),
        )
        return ret


class AntsApplyTransformsCompositeDisplacementFieldOutputOutputs(typing.NamedTuple):
    """
    Output object returned when calling `AntsApplyTransformsCompositeDisplacementFieldOutput(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image_outfile: OutputPathType
    """Warped image."""


@dataclasses.dataclass
class AntsApplyTransformsCompositeDisplacementFieldOutput:
    """
    Print out the displacement field based on the composite transform and the
    reference image.
    """
    composite_displacement_field: str
    """Output file name."""
    print_out_composite_warp_file: typing.Literal[0, 1] | None = None
    """Output a composite warp file instead of a transformed image."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        if self.print_out_composite_warp_file is not None:
            cargs.append("[" + self.composite_displacement_field + ",printOutCompositeWarpFile=" + str(self.print_out_composite_warp_file) + "]")
        return cargs
    
    def outputs(
        self,
        execution: Execution,
    ) -> AntsApplyTransformsCompositeDisplacementFieldOutputOutputs:
        """
        Collect output file paths.
        
        Args:
            execution: The execution object.
        Returns:
            NamedTuple of outputs (described in `AntsApplyTransformsCompositeDisplacementFieldOutputOutputs`).
        """
        ret = AntsApplyTransformsCompositeDisplacementFieldOutputOutputs(
            root=execution.output_file("."),
            output_image_outfile=execution.output_file(self.composite_displacement_field),
        )
        return ret


class AntsApplyTransformsGenericAffineTransformOutputOutputs(typing.NamedTuple):
    """
    Output object returned when calling `AntsApplyTransformsGenericAffineTransformOutput(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image_outfile: OutputPathType
    """Warped image."""


@dataclasses.dataclass
class AntsApplyTransformsGenericAffineTransformOutput:
    """
    Compose all affine transforms and (if boolean is set) calculate its inverse
    which is then written to an ITK file.
    """
    generic_affine_transform_file: str
    """Output file name."""
    calculate_inverse: typing.Literal[0, 1] | None = None
    """Calculate the inverse of the affine transform."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        if self.calculate_inverse is not None:
            cargs.append("Linear[" + self.generic_affine_transform_file + ",calculateInverse=" + str(self.calculate_inverse) + "]")
        return cargs
    
    def outputs(
        self,
        execution: Execution,
    ) -> AntsApplyTransformsGenericAffineTransformOutputOutputs:
        """
        Collect output file paths.
        
        Args:
            execution: The execution object.
        Returns:
            NamedTuple of outputs (described in `AntsApplyTransformsGenericAffineTransformOutputOutputs`).
        """
        ret = AntsApplyTransformsGenericAffineTransformOutputOutputs(
            root=execution.output_file("."),
            output_image_outfile=execution.output_file(self.generic_affine_transform_file),
        )
        return ret


@dataclasses.dataclass
class AntsApplyTransformsLinear:
    """
    Linear interpolation.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("Linear")
        return cargs


@dataclasses.dataclass
class AntsApplyTransformsNearestNeighbor:
    """
    Nearest neighbor interpolation.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("NearestNeighbor")
        return cargs


@dataclasses.dataclass
class AntsApplyTransformsMultiLabelnoparams:
    """
    Multi label interpolation.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("MultiLabel")
        return cargs


@dataclasses.dataclass
class AntsApplyTransformsSigma:
    """
    Sigma value.
    """
    sigma: float
    """Sigma value."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("sigma=" + str(self.sigma))
        return cargs


@dataclasses.dataclass
class AntsApplyTransformsAlpha:
    """
    Alpha value.
    """
    alpha: float
    """Alpha value."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("alpha=" + str(self.alpha))
        return cargs


@dataclasses.dataclass
class AntsApplyTransformsParam:
    params: list[typing.Union[AntsApplyTransformsSigma, AntsApplyTransformsAlpha]]
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("[" + ",".join([a for c in [s.run(execution) for s in self.params] for a in c]) + "]")
        return cargs


@dataclasses.dataclass
class AntsApplyTransformsMultiLabel:
    """
    Multi label interpolation.
    """
    params: AntsApplyTransformsParam
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("MultiLabel" + "".join(self.params.run(execution)))
        return cargs


@dataclasses.dataclass
class AntsApplyTransformsGaussian:
    """
    Gaussian interpolation.
    """
    sigma: float | None = None
    """Sigma value."""
    alpha: float | None = None
    """Alpha value."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        if self.sigma is not None or self.alpha is not None:
            cargs.append("Gaussian[sigma=" + (str(self.sigma) if (self.sigma is not None) else "") + ",alpha=" + (str(self.alpha) if (self.alpha is not None) else "") + "]")
        return cargs


@dataclasses.dataclass
class AntsApplyTransformsBspline:
    """
    BSpline interpolation.
    """
    order: int | None = None
    """Order value."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        if self.order is not None:
            cargs.append("BSpline[order=" + str(self.order) + "]")
        return cargs


@dataclasses.dataclass
class AntsApplyTransformsCosineWindowedSinc:
    """
    Cosine windowed sinc interpolation.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("CosineWindowedSinc")
        return cargs


@dataclasses.dataclass
class AntsApplyTransformsWelchWindowedSinc:
    """
    Welch windowed sinc interpolation.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("WelchWindowedSinc")
        return cargs


@dataclasses.dataclass
class AntsApplyTransformsHammingWindowedSinc:
    """
    Hamming windowed sinc interpolation.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("HammingWindowedSinc")
        return cargs


@dataclasses.dataclass
class AntsApplyTransformsLanczosWindowedSinc:
    """
    Lanczos windowed sinc interpolation.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("LanczosWindowedSinc")
        return cargs


@dataclasses.dataclass
class AntsApplyTransformsGenericLabel:
    """
    Generic label interpolation.
    """
    interpolator: str | None = None
    """Interpolator value."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        if self.interpolator is not None:
            cargs.append("GenericLabel[interpolator=" + self.interpolator + "]")
        return cargs


@dataclasses.dataclass
class AntsApplyTransformsTransformFileName:
    """
    Transform file name.
    """
    transform_file_name: InputPathType
    """Transform file name."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append(execution.input_file(self.transform_file_name))
        return cargs


@dataclasses.dataclass
class AntsApplyTransformsUseInverse:
    """
    Use inverse.
    """
    transform_file_name: InputPathType
    """Transform file name."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("[" + execution.input_file(self.transform_file_name) + ",useInverse]")
        return cargs


class AntsApplyTransformsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_apply_transforms(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: typing.Union[AntsApplyTransformsWarpedOutputOutputs, AntsApplyTransformsCompositeDisplacementFieldOutputOutputs, AntsApplyTransformsGenericAffineTransformOutputOutputs]
    """Outputs from `AntsApplyTransformsWarpedOutput` or
    `AntsApplyTransformsCompositeDisplacementFieldOutput` or
    `AntsApplyTransformsGenericAffineTransformOutput`."""


def ants_apply_transforms(
    input_image: InputPathType,
    reference_image: InputPathType,
    output: typing.Union[AntsApplyTransformsWarpedOutput, AntsApplyTransformsCompositeDisplacementFieldOutput, AntsApplyTransformsGenericAffineTransformOutput],
    dimensionality: typing.Literal[2, 3, 4] | None = None,
    input_image_type: typing.Literal[0, 1, 2, 3, 4, 5] | None = None,
    interpolation: typing.Union[AntsApplyTransformsLinear, AntsApplyTransformsNearestNeighbor, AntsApplyTransformsMultiLabelnoparams, AntsApplyTransformsMultiLabel, AntsApplyTransformsGaussian, AntsApplyTransformsBspline, AntsApplyTransformsCosineWindowedSinc, AntsApplyTransformsWelchWindowedSinc, AntsApplyTransformsHammingWindowedSinc, AntsApplyTransformsLanczosWindowedSinc, AntsApplyTransformsGenericLabel] | None = None,
    output_data_type: typing.Literal["char", "uchar", "short", "int", "float", "double", "default"] | None = None,
    transform: list[typing.Union[AntsApplyTransformsTransformFileName, AntsApplyTransformsUseInverse]] | None = None,
    default_value: float | None = None,
    static_cast_for_r: str | None = None,
    float_: typing.Literal[0, 1] | None = None,
    verbose: typing.Literal[0, 1] | None = None,
    runner: Runner | None = None,
) -> AntsApplyTransformsOutputs:
    """
    antsApplyTransforms, applied to an input image, transforms it according to a
    reference image and a transform (or a set of transforms).
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        input_image: Currently, the only input objects supported are image\
            objects. However, the current framework allows for warping of other\
            objects such as meshes and point sets.
        reference_image: For warping input images, the reference image defines\
            the spacing, origin, size, and direction of the output warped image.
        output: One can either output the warped image or, if the boolean is\
            set, one can print out the displacement field based on the composite\
            transform and the reference image. A third option is to compose all\
            affine transforms and (if boolean is set) calculate its inverse which\
            is then written to an ITK file.
        dimensionality: This option forces the image to be treated as a\
            specified-dimensional image. if not specified, antswarp tries to infer\
            the dimensionality from the input image.
        input_image_type: Option specifying the input image type of scalar\
            (default), vector, tensor, time series, or multi-channel. A time series\
            image is a scalar image defined by an additional dimension for the time\
            component whereas a multi-channel image is a vector image with only\
            spatial dimensions. Five-dimensional images are e.g., AFNI stats image.
        interpolation: Several interpolation options are available in ITK.\
            These have all been made available.
        output_data_type: Output image data type. This is a direct typecast;\
            output values are not rescaled. Default is to use the internal data\
            type (float or double). uchar is unsigned char; others are signed.\
            WARNING: Outputs will be incorrect (overflowed/reinterpreted) if values\
            exceed the range allowed by your choice. Note that some pixel types are\
            not supported by some image formats. e.g. int is not supported by jpg.
        transform: Several transform options are supported including all those\
            defined in the ITK library in addition to a deformation field\
            transform. The ordering of the transformations follows the ordering\
            specified on the command line. An identity transform is pushed onto the\
            transformation stack. Each new transform encountered on the command\
            line is also pushed onto the transformation stack. Then, to warp the\
            input object, each point comprising the input object is warped first\
            according to the last transform pushed onto the stack followed by the\
            second to last transform, etc. until the last transform encountered\
            which is the identity transform. Also, it should be noted that the\
            inverse transform can be accommodated with the usual caveat that such\
            an inverse must be defined by the specified transform class.
        default_value: Default voxel value to be used with input images only.\
            Specifies the voxel value when the input point maps outside the output\
            domain. With tensor input images, specifies the default voxel\
            eigenvalues.
        static_cast_for_r: Forces static cast in ReadTransform (for R).
        float_: Use float instead of double for computations.
        verbose: Verbose output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsApplyTransformsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_APPLY_TRANSFORMS_METADATA)
    cargs = []
    cargs.append("antsApplyTransforms")
    if dimensionality is not None:
        cargs.extend([
            "--dimensionality",
            str(dimensionality)
        ])
    if input_image_type is not None:
        cargs.extend([
            "--input-image-type",
            str(input_image_type)
        ])
    cargs.extend([
        "--input",
        execution.input_file(input_image)
    ])
    cargs.extend([
        "--reference-image",
        execution.input_file(reference_image)
    ])
    cargs.extend([
        "--output",
        *output.run(execution)
    ])
    if interpolation is not None:
        cargs.extend([
            "--interpolation",
            *interpolation.run(execution)
        ])
    if output_data_type is not None:
        cargs.extend([
            "--output-data-type",
            output_data_type
        ])
    if transform is not None:
        cargs.extend([
            "--transform",
            *[a for c in [s.run(execution) for s in transform] for a in c]
        ])
    if default_value is not None:
        cargs.extend([
            "--default-value",
            str(default_value)
        ])
    if static_cast_for_r is not None:
        cargs.extend([
            "--static-cast-for-R",
            static_cast_for_r
        ])
    if float_ is not None:
        cargs.extend([
            "--float",
            str(float_)
        ])
    if verbose is not None:
        cargs.extend([
            "--verbose",
            str(verbose)
        ])
    ret = AntsApplyTransformsOutputs(
        root=execution.output_file("."),
        output=output.outputs(execution),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANTS_APPLY_TRANSFORMS_METADATA",
    "AntsApplyTransformsAlpha",
    "AntsApplyTransformsBspline",
    "AntsApplyTransformsCompositeDisplacementFieldOutput",
    "AntsApplyTransformsCompositeDisplacementFieldOutputOutputs",
    "AntsApplyTransformsCosineWindowedSinc",
    "AntsApplyTransformsGaussian",
    "AntsApplyTransformsGenericAffineTransformOutput",
    "AntsApplyTransformsGenericAffineTransformOutputOutputs",
    "AntsApplyTransformsGenericLabel",
    "AntsApplyTransformsHammingWindowedSinc",
    "AntsApplyTransformsLanczosWindowedSinc",
    "AntsApplyTransformsLinear",
    "AntsApplyTransformsMultiLabel",
    "AntsApplyTransformsMultiLabelnoparams",
    "AntsApplyTransformsNearestNeighbor",
    "AntsApplyTransformsOutputs",
    "AntsApplyTransformsParam",
    "AntsApplyTransformsSigma",
    "AntsApplyTransformsTransformFileName",
    "AntsApplyTransformsUseInverse",
    "AntsApplyTransformsWarpedOutput",
    "AntsApplyTransformsWarpedOutputOutputs",
    "AntsApplyTransformsWelchWindowedSinc",
    "ants_apply_transforms",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

AFF2RIGID_METADATA = Metadata(
    id="1c5bd7f0035a88c49ed0e7fc0bc2b90357a5176f.boutiques",
    name="aff2rigid",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class Aff2rigidOutputs(typing.NamedTuple):
    """
    Output object returned when calling `aff2rigid(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def aff2rigid(
    input_transform: InputPathType,
    output_transform: str,
    runner: Runner | None = None,
) -> Aff2rigidOutputs:
    """
    Tool for converting affine transformations to rigid transformations.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_transform: Input FLIRT transform (12 DOF) from the input image to\
            standard space.
        output_transform: Output matrix which will convert the input image to\
            standard space using a 6 DOF transformation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Aff2rigidOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(AFF2RIGID_METADATA)
    cargs = []
    cargs.append("aff2rigid")
    cargs.append(execution.input_file(input_transform))
    cargs.append(output_transform)
    ret = Aff2rigidOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "AFF2RIGID_METADATA",
    "Aff2rigidOutputs",
    "aff2rigid",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

INFLATE_SUBJECT_LH_METADATA = Metadata(
    id="13f58b307e30c9d1d7c23e3d8eda03727c68266d.boutiques",
    name="inflate_subject-lh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class InflateSubjectLhOutputs(typing.NamedTuple):
    """
    Output object returned when calling `inflate_subject_lh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def inflate_subject_lh(
    input_folder: str,
    hostname_flag: bool = False,
    runner: Runner | None = None,
) -> InflateSubjectLhOutputs:
    """
    A tool to process and inflate left hemisphere subject data in FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_folder: Input folder containing subject data.
        hostname_flag: Flag to check hostname.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `InflateSubjectLhOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(INFLATE_SUBJECT_LH_METADATA)
    cargs = []
    cargs.extend([
        "-lh",
        "inflate_subject" + input_folder
    ])
    if hostname_flag:
        cargs.append("hostname")
    ret = InflateSubjectLhOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "INFLATE_SUBJECT_LH_METADATA",
    "InflateSubjectLhOutputs",
    "inflate_subject_lh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

INFLATE_SUBJECT_METADATA = Metadata(
    id="0f453fc5ea15ce4839c856ec25b28572898bd123.boutiques",
    name="inflate_subject",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class InflateSubjectOutputs(typing.NamedTuple):
    """
    Output object returned when calling `inflate_subject(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType | None
    """Output of inflate_subject command"""


def inflate_subject(
    args: str | None = None,
    runner: Runner | None = None,
) -> InflateSubjectOutputs:
    """
    Inflate subject script for FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        args: Arguments for the inflate_subject command.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `InflateSubjectOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(INFLATE_SUBJECT_METADATA)
    cargs = []
    cargs.append("inflate_subject")
    if args is not None:
        cargs.append(args)
    ret = InflateSubjectOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(args + "_output.txt") if (args is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "INFLATE_SUBJECT_METADATA",
    "InflateSubjectOutputs",
    "inflate_subject",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FS_TUTORIAL_DATA_METADATA = Metadata(
    id="80182cd74220da19e2c55dc09c1599b0b78de72e.boutiques",
    name="fs_tutorial_data",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FsTutorialDataOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fs_tutorial_data(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    tutorial_data_dir: OutputPathType
    """Directory where tutorial data will be downloaded and installed."""


def fs_tutorial_data(
    rsync_options: list[str] | None = None,
    runner: Runner | None = None,
) -> FsTutorialDataOutputs:
    """
    Tool to download and install FreeSurfer tutorial data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        rsync_options: Additional rsync options for downloading tutorial data.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FsTutorialDataOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FS_TUTORIAL_DATA_METADATA)
    cargs = []
    cargs.append("fs_tutorial_data")
    if rsync_options is not None:
        cargs.extend(rsync_options)
    ret = FsTutorialDataOutputs(
        root=execution.output_file("."),
        tutorial_data_dir=execution.output_file("/usr/local/freesurfer/subjects/tutorial_data"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FS_TUTORIAL_DATA_METADATA",
    "FsTutorialDataOutputs",
    "fs_tutorial_data",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

WMEDITS2SURF_METADATA = Metadata(
    id="e8eb1a9b712eb53b8fd7c00668424bc559f7cff6.boutiques",
    name="wmedits2surf",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Wmedits2surfOutputs(typing.NamedTuple):
    """
    Output object returned when calling `wmedits2surf(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    lh_wmerase: OutputPathType
    """Left hemisphere white matter erase surface file."""
    rh_wmerase: OutputPathType
    """Right hemisphere white matter erase surface file."""
    lh_wmfill: OutputPathType
    """Left hemisphere white matter fill surface file."""
    rh_wmfill: OutputPathType
    """Right hemisphere white matter fill surface file."""
    wm_erase_stats: OutputPathType
    """Statistics on the number of voxels erased."""
    wm_fill_stats: OutputPathType
    """Statistics on the number of voxels filled."""


def wmedits2surf(
    subject: str,
    self: bool = False,
    overwrite: bool = False,
    tmp_dir: str | None = None,
    cleanup: bool = False,
    no_cleanup: bool = False,
    debug: bool = False,
    lh: bool = False,
    rh: bool = False,
    no_surfs: bool = False,
    runner: Runner | None = None,
) -> Wmedits2surfOutputs:
    """
    Computes binary maps of surface locations where the wm.mgz has been edited.
    Creates files for each hemisphere for each type of edit.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: Subject identifier.
        overwrite: Force overwriting of existing results.
        tmp_dir: Temporary directory.
        cleanup: Cleanup temporary files after execution.
        no_cleanup: Do not cleanup temporary files after execution.
        debug: Debug mode.
        lh: Only do left hemisphere.
        rh: Only do right hemisphere.
        no_surfs: Do not compute surfaces, only count stats.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Wmedits2surfOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(WMEDITS2SURF_METADATA)
    cargs = []
    cargs.append("wmedits2surf")
    cargs.extend([
        "--s",
        subject
    ])
    if self:
        cargs.append("--self")
    if overwrite:
        cargs.append("--overwrite")
    if tmp_dir is not None:
        cargs.extend([
            "--tmp",
            tmp_dir
        ])
    if cleanup:
        cargs.append("--cleanup")
    if no_cleanup:
        cargs.append("--no-cleanup")
    if debug:
        cargs.append("--debug")
    if lh:
        cargs.append("--lh")
    if rh:
        cargs.append("--rh")
    if no_surfs:
        cargs.append("--no-surfs")
    ret = Wmedits2surfOutputs(
        root=execution.output_file("."),
        lh_wmerase=execution.output_file("subject/surf/lh.wmerase.fsa.mgh"),
        rh_wmerase=execution.output_file("subject/surf/rh.wmerase.fsa.mgh"),
        lh_wmfill=execution.output_file("subject/surf/lh.wmfill.fsa.mgh"),
        rh_wmfill=execution.output_file("subject/surf/rh.wmfill.fsa.mgh"),
        wm_erase_stats=execution.output_file("subject/stats/wm.erase.dat"),
        wm_fill_stats=execution.output_file("subject/stats/wm.fill.dat"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "WMEDITS2SURF_METADATA",
    "Wmedits2surfOutputs",
    "wmedits2surf",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ADJUNCT_SUMA_FS_MASK_AND_QC_METADATA = Metadata(
    id="e333368d139aab06ce173382ee2a0cb69f091a99.boutiques",
    name="adjunct_suma_fs_mask_and_qc",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AdjunctSumaFsMaskAndQcOutputs(typing.NamedTuple):
    """
    Output object returned when calling `adjunct_suma_fs_mask_and_qc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    fs_parc_wb_mask: OutputPathType
    """Whole brain mask based on the FS parcellation created by this script."""
    qc_image_00: OutputPathType
    """QC image with overlay of brainmask.nii* volume in red and parcellated
    subset in black."""
    qc_image_01: OutputPathType
    """QC image with overlay of fs_parc_wb_mask.nii.gz."""
    qc_image_02: OutputPathType
    """QC image with overlay of tissue segmentations."""
    qc_image_03: OutputPathType
    """QC image with overlay of GM."""
    qc_image_04: OutputPathType
    """QC image with overlay of WM."""
    qc_image_05: OutputPathType
    """QC image with overlay of "2000" atlas parcellation."""


def adjunct_suma_fs_mask_and_qc(
    subj_id: str,
    suma_dir: str,
    no_clean: bool = False,
    help_: bool = False,
    hview: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> AdjunctSumaFsMaskAndQcOutputs:
    """
    Script for quickly making some QC images for the SUMA/ directory created by
    @SUMA_Make_Spec_FS after running FreeSurfer's recon-all.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        subj_id: Subject ID.
        suma_dir: SUMA/ directory output by AFNI's @SUMA_Make_Spec_FS.
        no_clean: Do not remove temporary working subdirectory (default: remove\
            it).
        help_: Show help.
        hview: Show help in text editor.
        version: Show version.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AdjunctSumaFsMaskAndQcOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ADJUNCT_SUMA_FS_MASK_AND_QC_METADATA)
    cargs = []
    cargs.append("adjunct_suma_fs_mask_and_qc")
    cargs.extend([
        "-sid",
        subj_id
    ])
    cargs.extend([
        "-suma_dir",
        suma_dir
    ])
    if no_clean:
        cargs.append("-no_clean")
    if help_:
        cargs.append("-help")
    if hview:
        cargs.append("-hview")
    if version:
        cargs.append("-ver")
    ret = AdjunctSumaFsMaskAndQcOutputs(
        root=execution.output_file("."),
        fs_parc_wb_mask=execution.output_file("SUMA/fs_parc_wb_mask.nii.gz"),
        qc_image_00=execution.output_file("SUMA/qc_00*.jpg"),
        qc_image_01=execution.output_file("SUMA/qc_01*.jpg"),
        qc_image_02=execution.output_file("SUMA/qc_02*.jpg"),
        qc_image_03=execution.output_file("SUMA/qc_03*.jpg"),
        qc_image_04=execution.output_file("SUMA/qc_04*.jpg"),
        qc_image_05=execution.output_file("SUMA/qc_05*.jpg"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ADJUNCT_SUMA_FS_MASK_AND_QC_METADATA",
    "AdjunctSumaFsMaskAndQcOutputs",
    "adjunct_suma_fs_mask_and_qc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_EXTRACT_MAIN_COMPONENT_METADATA = Metadata(
    id="3c629f67071bd64777c7e0eb6653d23ab4e436c0.boutiques",
    name="mris_extract_main_component",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisExtractMainComponentOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_extract_main_component(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_surface_file: OutputPathType
    """Extracted main component of the input surface"""


def mris_extract_main_component(
    input_surface: InputPathType,
    output_surface: str,
    runner: Runner | None = None,
) -> MrisExtractMainComponentOutputs:
    """
    Tool for extracting the main component from a surface input.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_surface: Input surface file (e.g. lh.white).
        output_surface: Output surface file (e.g. lh.white.main).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisExtractMainComponentOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_EXTRACT_MAIN_COMPONENT_METADATA)
    cargs = []
    cargs.append("mris_extract_main_component")
    cargs.append(execution.input_file(input_surface))
    cargs.append(output_surface)
    ret = MrisExtractMainComponentOutputs(
        root=execution.output_file("."),
        output_surface_file=execution.output_file(output_surface),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_EXTRACT_MAIN_COMPONENT_METADATA",
    "MrisExtractMainComponentOutputs",
    "mris_extract_main_component",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_DEFACER_METADATA = Metadata(
    id="1b6a737bd3d80434774e54823d1c3ab67e9eccdf.boutiques",
    name="mri_defacer",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriDefacerOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_defacer(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_defacer(
    input_volume: InputPathType,
    headmask: InputPathType,
    tempsurf: InputPathType,
    defaced_volume: str,
    templabel: list[InputPathType] | None = None,
    watermark: float | None = None,
    facemask: str | None = None,
    fill_constants: list[float] | None = None,
    exclude_mask: InputPathType | None = None,
    tempreg: InputPathType | None = None,
    minsurfpath: str | None = None,
    maxsurfpath: str | None = None,
    distbounds: InputPathType | None = None,
    distoverlay: InputPathType | None = None,
    distdat: InputPathType | None = None,
    statspath: InputPathType | None = None,
    output_tempsurf: InputPathType | None = None,
    apply_to_volume: list[str] | None = None,
    ripple_center: list[float] | None = None,
    apply_ripple: list[str] | None = None,
    diagnostic_level: float | None = None,
    debug: bool = False,
    checkopts: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> MriDefacerOutputs:
    """
    Tool for defacing MRI images to remove facial features.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Input volume.
        headmask: Head mask volume.
        tempsurf: Template surface file.
        defaced_volume: Output defaced volume.
        templabel: Template label, specify one or multiple labels.
        watermark: Watermark density.
        facemask: Face mask volume.
        fill_constants: Constants for filling within/outside the mask.
        exclude_mask: Mask to exclude from defacing.
        tempreg: Registration file to apply to surface.
        minsurfpath: Output minimum surface path.
        maxsurfpath: Output maximum surface path.
        distbounds: File with distance bounds for each label.
        distoverlay: Overlay file showing distance for each vertex.
        distdat: File with distances for each vertex.
        statspath: Statistics path for nxmask with means and modes.
        output_tempsurf: Output template surface after watermark/ripple.
        apply_to_volume: Apply face mask and registration to another volume.
        ripple_center: Center of ripple effect.
        apply_ripple: Apply ripple effect on surface.
        diagnostic_level: Set diagnostic level.
        debug: Turn on debugging.
        checkopts: Check options and exit without executing.
        version: Print version and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriDefacerOutputs`).
    """
    if apply_to_volume is not None and (len(apply_to_volume) != 4): 
        raise ValueError(f"Length of 'apply_to_volume' must be 4 but was {len(apply_to_volume)}")
    if apply_ripple is not None and (len(apply_ripple) != 6): 
        raise ValueError(f"Length of 'apply_ripple' must be 6 but was {len(apply_ripple)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_DEFACER_METADATA)
    cargs = []
    cargs.append("mri_defacer")
    cargs.extend([
        "-i",
        execution.input_file(input_volume)
    ])
    cargs.extend([
        "-hm",
        execution.input_file(headmask)
    ])
    cargs.extend([
        "-ts",
        execution.input_file(tempsurf)
    ])
    if templabel is not None:
        cargs.extend([
            "--l",
            *[execution.input_file(f) for f in templabel]
        ])
    if watermark is not None:
        cargs.extend([
            "--w",
            str(watermark)
        ])
    cargs.extend([
        "-o",
        defaced_volume
    ])
    if facemask is not None:
        cargs.extend([
            "--m",
            facemask
        ])
    if fill_constants is not None:
        cargs.extend([
            "--fill-const",
            *map(str, fill_constants)
        ])
    if exclude_mask is not None:
        cargs.extend([
            "--xmask",
            execution.input_file(exclude_mask)
        ])
    if tempreg is not None:
        cargs.extend([
            "--reg",
            execution.input_file(tempreg)
        ])
    if minsurfpath is not None:
        cargs.extend([
            "--min",
            minsurfpath
        ])
    if maxsurfpath is not None:
        cargs.extend([
            "--max",
            maxsurfpath
        ])
    if distbounds is not None:
        cargs.extend([
            "--distbounds",
            execution.input_file(distbounds)
        ])
    if distoverlay is not None:
        cargs.extend([
            "--distoverlay",
            execution.input_file(distoverlay)
        ])
    if distdat is not None:
        cargs.extend([
            "--distdat",
            execution.input_file(distdat)
        ])
    if statspath is not None:
        cargs.extend([
            "--stats",
            execution.input_file(statspath)
        ])
    if output_tempsurf is not None:
        cargs.extend([
            "--ots",
            execution.input_file(output_tempsurf)
        ])
    if apply_to_volume is not None:
        cargs.extend([
            "--apply",
            *apply_to_volume
        ])
    if ripple_center is not None:
        cargs.extend([
            "--ripple-center",
            *map(str, ripple_center)
        ])
    if apply_ripple is not None:
        cargs.extend([
            "--apply-ripple",
            *apply_ripple
        ])
    if diagnostic_level is not None:
        cargs.extend([
            "--gdiag",
            str(diagnostic_level)
        ])
    if debug:
        cargs.append("--debug")
    if checkopts:
        cargs.append("--checkopts")
    if version:
        cargs.append("--version")
    ret = MriDefacerOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_DEFACER_METADATA",
    "MriDefacerOutputs",
    "mri_defacer",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LABEL_ELDERLY_SUBJECT_METADATA = Metadata(
    id="7a5cf9786ead1cc29d5308081c97520e6bd9cf60.boutiques",
    name="label_elderly_subject",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class LabelElderlySubjectOutputs(typing.NamedTuple):
    """
    Output object returned when calling `label_elderly_subject(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    labeled_volume: OutputPathType
    """Labeled output volume"""


def label_elderly_subject(
    norm_volume: InputPathType,
    transform_lta: InputPathType,
    aseg_volume: InputPathType,
    classifier_array: InputPathType | None = None,
    runner: Runner | None = None,
) -> LabelElderlySubjectOutputs:
    """
    Tool for labeling brain structures in MRI images of elderly subjects using
    Freesurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        norm_volume: Normalized input volume (e.g. norm.mgz).
        transform_lta: Transformation file (e.g. talairach.lta).
        aseg_volume: Asegmentation volume file (e.g. aseg.mgz).
        classifier_array: Classifier array file (e.g. mixed.gca).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LabelElderlySubjectOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LABEL_ELDERLY_SUBJECT_METADATA)
    cargs = []
    cargs.append("label_elderly_subject")
    cargs.append(execution.input_file(norm_volume))
    cargs.append(execution.input_file(transform_lta))
    if classifier_array is not None:
        cargs.append(execution.input_file(classifier_array))
    cargs.append(execution.input_file(aseg_volume))
    ret = LabelElderlySubjectOutputs(
        root=execution.output_file("."),
        labeled_volume=execution.output_file(pathlib.Path(aseg_volume).name + "_labeled.mgz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LABEL_ELDERLY_SUBJECT_METADATA",
    "LabelElderlySubjectOutputs",
    "label_elderly_subject",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLCOMPLEX_METADATA = Metadata(
    id="7b0a519cc8c2bf2ab20b79371bcb5b1194faec91.boutiques",
    name="fslcomplex",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FslcomplexOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslcomplex(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    result_output_file: OutputPathType
    """The resulting output file from the specified operation."""


def fslcomplex(
    input_file: InputPathType,
    output_file: InputPathType,
    output_type: typing.Literal["-realabs", "-realphase", "-realpolar", "-realcartesian", "-complex", "-complexpolar", "-complexsplit", "-complexmerge", "-copyonly"],
    start_vol: int | None = None,
    end_vol: int | None = None,
    runner: Runner | None = None,
) -> FslcomplexOutputs:
    """
    Tool for manipulating complex-valued MR data.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_file: Input volume (e.g. complexvol.nii.gz).
        output_file: Output volume (e.g. absvol.nii.gz).
        output_type: Output type (determines the operation to perform).
        start_vol: Start volume (optional).
        end_vol: End volume (optional).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslcomplexOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLCOMPLEX_METADATA)
    cargs = []
    cargs.append("fslcomplex")
    cargs.append(execution.input_file(input_file))
    cargs.append(execution.input_file(output_file))
    cargs.append(output_type)
    if start_vol is not None:
        cargs.append(str(start_vol))
    if end_vol is not None:
        cargs.append(str(end_vol))
    ret = FslcomplexOutputs(
        root=execution.output_file("."),
        result_output_file=execution.output_file(pathlib.Path(output_file).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLCOMPLEX_METADATA",
    "FslcomplexOutputs",
    "fslcomplex",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__CLUST_EXP_RUN_SHINY_METADATA = Metadata(
    id="fda3a7d2925f29a17f3a4aecaecf82a67d6aa1fc.boutiques",
    name="@ClustExp_run_shiny",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VClustExpRunShinyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__clust_exp_run_shiny(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__clust_exp_run_shiny(
    directory: str,
    help_: bool = False,
    runner: Runner | None = None,
) -> VClustExpRunShinyOutputs:
    """
    Launch a shiny app that was created by ClustExp_StatParse.py.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        directory: Folder created by ClustExp_StatParse.py.
        help_: Show help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VClustExpRunShinyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__CLUST_EXP_RUN_SHINY_METADATA)
    cargs = []
    cargs.append("@ClustExp_run_shiny")
    cargs.append(directory)
    if help_:
        cargs.append("-help")
    ret = VClustExpRunShinyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VClustExpRunShinyOutputs",
    "V__CLUST_EXP_RUN_SHINY_METADATA",
    "v__clust_exp_run_shiny",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_RELABEL_NONWM_HYPOS_METADATA = Metadata(
    id="93faec099d80076ace8a12bddc7f7a4affe02681.boutiques",
    name="mri_relabel_nonwm_hypos",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriRelabelNonwmHyposOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_relabel_nonwm_hypos(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_segmentation: OutputPathType
    """Output segmentation with non-WM hypointensities relabeled."""


def mri_relabel_nonwm_hypos(
    inputseg: InputPathType,
    outputseg: str,
    segments: list[str] | None = None,
    seg_default: bool = False,
    debug: bool = False,
    checkopts: bool = False,
    runner: Runner | None = None,
) -> MriRelabelNonwmHyposOutputs:
    """
    Relabels non-WM hypointensities based on proximity to a nearby label.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        inputseg: Input segmentation file with non-wm-hypos labeled as 80, 81,\
            or 82.
        outputseg: Output segmentation file with non-wm-hypos relabeled.
        segments: Label hypos adjacent to specified segment as a new segment\
            (can be used multiple times).
        seg_default: Use the default relabeling scheme.
        debug: Turn on debugging.
        checkopts: Don't run anything, just check options and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriRelabelNonwmHyposOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_RELABEL_NONWM_HYPOS_METADATA)
    cargs = []
    cargs.append("mri_relabel_nonwm_hypos")
    cargs.extend([
        "-i",
        "-" + execution.input_file(inputseg)
    ])
    cargs.extend([
        "-o",
        "-" + outputseg
    ])
    if segments is not None:
        cargs.extend([
            "--seg",
            *segments
        ])
    if seg_default:
        cargs.append("--seg-default")
    if debug:
        cargs.append("--debug")
    if checkopts:
        cargs.append("--checkopts")
    ret = MriRelabelNonwmHyposOutputs(
        root=execution.output_file("."),
        out_segmentation=execution.output_file(outputseg),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_RELABEL_NONWM_HYPOS_METADATA",
    "MriRelabelNonwmHyposOutputs",
    "mri_relabel_nonwm_hypos",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DCOPY_METADATA = Metadata(
    id="4b8187d004c6f4ba95518e709ad1f9b3eb4ed322.boutiques",
    name="3dcopy",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dcopyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dcopy(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_3dcopy(
    verbose: bool = False,
    denote: bool = False,
    runner: Runner | None = None,
) -> V3dcopyOutputs:
    """
    3dcopy copies datasets with or without altering prefixes and converting formats.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        verbose: Print progress reports.
        denote: Remove any Notes from the file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dcopyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DCOPY_METADATA)
    cargs = []
    cargs.append("3dcopy")
    if verbose:
        cargs.append("-verb")
    if denote:
        cargs.append("-denote")
    cargs.append("{OLD_PREFIX}+{VIEW}")
    cargs.append("{NEW_PREFIX}")
    ret = V3dcopyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dcopyOutputs",
    "V_3DCOPY_METADATA",
    "v_3dcopy",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANTSUSE_LANDMARK_IMAGES_TO_GET_BSPLINE_DISPLACEMENT_FIELD_METADATA = Metadata(
    id="7af4a9a784989ddd8ff76f3225c25b7355e86a75.boutiques",
    name="ANTSUseLandmarkImagesToGetBSplineDisplacementField",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class AntsuseLandmarkImagesToGetBsplineDisplacementFieldOutputs(typing.NamedTuple):
    """
    Output object returned when calling `antsuse_landmark_images_to_get_bspline_displacement_field(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    displacement_field: OutputPathType
    """The resultant displacement field for the registration process."""


def antsuse_landmark_images_to_get_bspline_displacement_field(
    fixed_image_with_labeled_landmarks: InputPathType,
    moving_image_with_labeled_landmarks: InputPathType,
    output_displacement_field: str,
    mesh_size: str,
    number_of_levels: int,
    order: int | None = 3,
    enforce_stationary_boundaries: int | None = 1,
    landmark_weights: InputPathType | None = None,
    runner: Runner | None = None,
) -> AntsuseLandmarkImagesToGetBsplineDisplacementFieldOutputs:
    """
    We expect the input images to be (1) N-ary (2) in the same physical space as the
    images you want to register and (3) to have the same landmark points defined
    within them. Landmarks will be defined from the center of mass of the labels in
    the input images. You can use ITK-snap to generate the label images. The
    optional landmarks weights are read from a text file where each row is either:
    "label,labelWeight" or "labelWeight". If the latter format is used, the label
    weights are assumed to be arranged in ascending order by label.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        fixed_image_with_labeled_landmarks: The fixed image with labeled\
            landmarks.
        moving_image_with_labeled_landmarks: The moving image with labeled\
            landmarks.
        output_displacement_field: The output displacement field file.
        mesh_size: The mesh size specified as meshSize[0]xmeshSize[1]x...
        number_of_levels: The number of levels in the B-spline hierarchy.
        order: The order of the B-spline (default is 3).
        enforce_stationary_boundaries: Whether to enforce stationary boundaries\
            (default is 1).
        landmark_weights: Optional text file containing landmark weights. Each\
            row is either "label,labelWeight" or "labelWeight". If the latter\
            format is used, the weights are assumed to be arranged in ascending\
            order by label.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsuseLandmarkImagesToGetBsplineDisplacementFieldOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTSUSE_LANDMARK_IMAGES_TO_GET_BSPLINE_DISPLACEMENT_FIELD_METADATA)
    cargs = []
    cargs.append("ANTSUseLandmarkImagesToGetBSplineDisplacementField")
    cargs.append(execution.input_file(fixed_image_with_labeled_landmarks))
    cargs.append(execution.input_file(moving_image_with_labeled_landmarks))
    cargs.append(output_displacement_field)
    cargs.append(mesh_size)
    cargs.append(str(number_of_levels))
    if order is not None:
        cargs.append(str(order))
    if enforce_stationary_boundaries is not None:
        cargs.append(str(enforce_stationary_boundaries))
    if landmark_weights is not None:
        cargs.append(execution.input_file(landmark_weights))
    ret = AntsuseLandmarkImagesToGetBsplineDisplacementFieldOutputs(
        root=execution.output_file("."),
        displacement_field=execution.output_file(output_displacement_field),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANTSUSE_LANDMARK_IMAGES_TO_GET_BSPLINE_DISPLACEMENT_FIELD_METADATA",
    "AntsuseLandmarkImagesToGetBsplineDisplacementFieldOutputs",
    "antsuse_landmark_images_to_get_bspline_displacement_field",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FEAT_METADATA = Metadata(
    id="dbbaab6a8f5e02741899d759348059945801df59.boutiques",
    name="feat",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FeatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `feat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dir: OutputPathType
    """Output directory containing all results from FEAT"""


def feat(
    design_file: InputPathType,
    runner: Runner | None = None,
) -> FeatOutputs:
    """
    fMRI Expert Analysis Tool.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        design_file: FEAT design file (e.g. design.fsf).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FeatOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FEAT_METADATA)
    cargs = []
    cargs.append("feat")
    cargs.append(execution.input_file(design_file))
    ret = FeatOutputs(
        root=execution.output_file("."),
        output_dir=execution.output_file("design.feat"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FEAT_METADATA",
    "FeatOutputs",
    "feat",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

REMOVE_TALAIRACH_METADATA = Metadata(
    id="4b227d57c6cc0632758ead5783a3cd254592158b.boutiques",
    name="remove_talairach",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class RemoveTalairachOutputs(typing.NamedTuple):
    """
    Output object returned when calling `remove_talairach(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_volume: OutputPathType
    """Output volume with Talairach transformation removed"""


def remove_talairach(
    input_file: InputPathType,
    output_file: str,
    runner: Runner | None = None,
) -> RemoveTalairachOutputs:
    """
    A tool for removing the Talairach transformation from a volume.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input volume with Talairach transformation (e.g.,\
            volume.nii).
        output_file: Output volume after removing Talairach transformation\
            (e.g., volume_notal.nii).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RemoveTalairachOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(REMOVE_TALAIRACH_METADATA)
    cargs = []
    cargs.append("remove_talairach")
    cargs.append(execution.input_file(input_file))
    cargs.append(output_file)
    ret = RemoveTalairachOutputs(
        root=execution.output_file("."),
        output_volume=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "REMOVE_TALAIRACH_METADATA",
    "RemoveTalairachOutputs",
    "remove_talairach",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CONVERT_CDIFLIST_TO_GRADS_METADATA = Metadata(
    id="881be0d2d254f2047a6c704bea01fe398f0290f3.boutiques",
    name="convert_cdiflist_to_grads",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class ConvertCdiflistToGradsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `convert_cdiflist_to_grads(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_rvec: OutputPathType
    """Row-format of gradients (unit magnitude)."""
    output_bval: OutputPathType
    """Row-format of bvals."""
    output_cvec: OutputPathType
    """Col-format of gradients (scaled by b-values)."""


def convert_cdiflist_to_grads(
    cdiflist: InputPathType,
    bval_max: float,
    prefix: str,
    ver: bool = False,
    date: bool = False,
    help_: bool = False,
    hview: bool = False,
    runner: Runner | None = None,
) -> ConvertCdiflistToGradsOutputs:
    """
    This program reads in a GE cdiflist and outputs gradient file and file of
    bvalues for subsequent processing.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        cdiflist: Name(s) of cdiflist text file output by GE scanners when\
            acquiring DWIs.
        bval_max: Max bvalue used, which provides a reference value for scaling\
            everything else.
        prefix: Output basename for the subsequent grad and bvalue files\
            (suffix and extensions will be added).
        ver: Display current version.
        date: Display release/editing date of current version.
        help_: Display help in terminal.
        hview: Display help in terminal.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ConvertCdiflistToGradsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CONVERT_CDIFLIST_TO_GRADS_METADATA)
    cargs = []
    cargs.append("convert_cdiflist_to_grads.py")
    cargs.extend([
        "-cdiflist",
        execution.input_file(cdiflist)
    ])
    cargs.extend([
        "-bval_max",
        str(bval_max)
    ])
    cargs.extend([
        "-prefix",
        prefix
    ])
    if ver:
        cargs.append("-ver")
    if date:
        cargs.append("-date")
    if help_:
        cargs.append("-help")
    if hview:
        cargs.append("-h")
    ret = ConvertCdiflistToGradsOutputs(
        root=execution.output_file("."),
        output_rvec=execution.output_file(prefix + "_rvec.dat"),
        output_bval=execution.output_file(prefix + "_bval.dat"),
        output_cvec=execution.output_file(prefix + "_cvec.dat"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CONVERT_CDIFLIST_TO_GRADS_METADATA",
    "ConvertCdiflistToGradsOutputs",
    "convert_cdiflist_to_grads",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_TALAIRACH_METADATA = Metadata(
    id="2a27ec50232d56f8e8e079035c459f747d644292.boutiques",
    name="mris_talairach",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisTalairachOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_talairach(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_talairach(
    input_image: InputPathType,
    runner: Runner | None = None,
) -> MrisTalairachOutputs:
    """
    Transforms an MRI surface into Talairach space.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_image: Input image file to be transformed into Talairach space.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisTalairachOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_TALAIRACH_METADATA)
    cargs = []
    cargs.append("mris_talairach")
    cargs.append(execution.input_file(input_image))
    ret = MrisTalairachOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_TALAIRACH_METADATA",
    "MrisTalairachOutputs",
    "mris_talairach",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_SYNTHSR_HYPERFINE_METADATA = Metadata(
    id="8af5c94607ef31a7bceecdbe213a0b0e78928e27.boutiques",
    name="mri_synthsr_hyperfine",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriSynthsrHyperfineOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_synthsr_hyperfine(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    synthetic_mprage: OutputPathType
    """Synthetic 1mm MP-RAGE(s) generated from T1 and T2 inputs"""


def mri_synthsr_hyperfine(
    t1_image: InputPathType,
    t2_image: InputPathType,
    output: str,
    threads: float | None = 1,
    cpu: bool = False,
    runner: Runner | None = None,
) -> MriSynthsrHyperfineOutputs:
    """
    Implementation of SynthSR that generates a synthetic 1mm MP-RAGE from a pair of
    T1-T2 standard Hyperfine scans (1.5x1.5x5mm axial).
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        t1_image: T1 image(s) to super-resolve, at native 1.5x1.5x5 axial\
            resolution. Can be a path to an image or to a folder.
        t2_image: T2 image(s). Must be a folder if --t1 designates a folder.\
            These must be registered to the T1s, in physical coordinates (i.e.,\
            with the headers, do NOT resample when registering; see instructions on\
            FreeSurfer wiki).
        output: Output(s), i.e. synthetic 1mm MP-RAGE(s). Must be a folder if\
            --t1 designates a folder.
        threads: (optional) Number of cores to be used. Default is 1.
        cpu: (optional) Enforce running with CPU rather than GPU.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriSynthsrHyperfineOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_SYNTHSR_HYPERFINE_METADATA)
    cargs = []
    cargs.append("mri_synthsr_hyperfine")
    cargs.extend([
        "--t1",
        execution.input_file(t1_image)
    ])
    cargs.extend([
        "--t2",
        execution.input_file(t2_image)
    ])
    cargs.extend([
        "--o",
        output
    ])
    if threads is not None:
        cargs.extend([
            "--threads",
            str(threads)
        ])
    if cpu:
        cargs.append("--cpu")
    ret = MriSynthsrHyperfineOutputs(
        root=execution.output_file("."),
        synthetic_mprage=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_SYNTHSR_HYPERFINE_METADATA",
    "MriSynthsrHyperfineOutputs",
    "mri_synthsr_hyperfine",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_MOTION_CORRECT_METADATA = Metadata(
    id="3cfbb0cc88f7a83298127f974e5ce214fa8cdbf7.boutiques",
    name="mri_motion_correct",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriMotionCorrectOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_motion_correct(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    corrected_outfile: OutputPathType
    """Corrected MRI image output file."""


def mri_motion_correct(
    outfile: str,
    infiles: list[InputPathType],
    runner: Runner | None = None,
) -> MriMotionCorrectOutputs:
    """
    Tool for correcting motion in MRI scans.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        outfile: Output file where the corrected MRI image(s) will be stored.
        infiles: Input MRI image files to be corrected.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriMotionCorrectOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_MOTION_CORRECT_METADATA)
    cargs = []
    cargs.append("mri_motion_correct")
    cargs.append(outfile)
    cargs.extend([execution.input_file(f) for f in infiles])
    ret = MriMotionCorrectOutputs(
        root=execution.output_file("."),
        corrected_outfile=execution.output_file(outfile),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_MOTION_CORRECT_METADATA",
    "MriMotionCorrectOutputs",
    "mri_motion_correct",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

PARC_ATLAS_JACKKNIFE_TEST_METADATA = Metadata(
    id="c3bca782ff73ffb7144b8a68ae203b8cb4791e7f.boutiques",
    name="parc_atlas_jackknife_test",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class ParcAtlasJackknifeTestOutputs(typing.NamedTuple):
    """
    Output object returned when calling `parc_atlas_jackknife_test(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    jackknife_output: OutputPathType
    """Output files written to the directory named 'jackknife'."""


def parc_atlas_jackknife_test(
    register: bool = False,
    reg_dist: str | None = None,
    reg_append: str | None = None,
    reg_copy: str | None = None,
    train: bool = False,
    classify: bool = False,
    test: bool = False,
    all_: bool = False,
    subjects_dir: str | None = None,
    freesurfer_home: str | None = None,
    binaries_path: str | None = None,
    dontrun: bool = False,
    runner: Runner | None = None,
) -> ParcAtlasJackknifeTestOutputs:
    """
    Tool for conducting a jackknife accuracy test using FreeSurfer atlases.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        register: Run mris_register: creates .sphere.reg files.
        reg_dist: Run mris_register with '-dist <arg>' flag.
        reg_append: Append <string> to end of ?h.sphere.reg.
        reg_copy: Copy ?h.sphere.reg<string> ?h.sphere.reg.
        train: Run mris_ca_train: creates .gcs files.
        classify: Run mris_ca_label: creates .annot files.
        test: Run mris_compute_parc_overlap.
        all_: Run train, classify, and test.
        subjects_dir: Override default subjects directory.
        freesurfer_home: Source a new FREESURFER_HOME.
        binaries_path: Specify override path to binaries.
        dontrun: Don't execute the commands.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ParcAtlasJackknifeTestOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(PARC_ATLAS_JACKKNIFE_TEST_METADATA)
    cargs = []
    cargs.append("parc_atlas_jackknife_test")
    if register:
        cargs.append("-register")
    if reg_dist is not None:
        cargs.extend([
            "-reg_dist",
            reg_dist
        ])
    if reg_append is not None:
        cargs.extend([
            "-reg_append",
            reg_append
        ])
    if reg_copy is not None:
        cargs.extend([
            "-reg_copy",
            reg_copy
        ])
    if train:
        cargs.append("-train")
    if classify:
        cargs.append("-classify")
    if test:
        cargs.append("-test")
    if all_:
        cargs.append("-all")
    if subjects_dir is not None:
        cargs.extend([
            "-sd",
            subjects_dir
        ])
    if freesurfer_home is not None:
        cargs.extend([
            "-fshome",
            freesurfer_home
        ])
    if binaries_path is not None:
        cargs.extend([
            "-binhome",
            binaries_path
        ])
    if dontrun:
        cargs.append("-dontrun")
    ret = ParcAtlasJackknifeTestOutputs(
        root=execution.output_file("."),
        jackknife_output=execution.output_file("jackknife/*"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "PARC_ATLAS_JACKKNIFE_TEST_METADATA",
    "ParcAtlasJackknifeTestOutputs",
    "parc_atlas_jackknife_test",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

EXTRACT_REGION_FROM_IMAGE_BY_MASK_METADATA = Metadata(
    id="aec2f60db8048987a495410600ad2f857750da61.boutiques",
    name="ExtractRegionFromImageByMask",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class ExtractRegionFromImageByMaskOutputs(typing.NamedTuple):
    """
    Output object returned when calling `extract_region_from_image_by_mask(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def extract_region_from_image_by_mask(
    image_dimension: int,
    input_image: InputPathType,
    output_image: InputPathType,
    label_mask_image: InputPathType,
    label: int | None = 1,
    pad_radius: int | None = 0,
    runner: Runner | None = None,
) -> ExtractRegionFromImageByMaskOutputs:
    """
    Extract a sub-region from an image using the bounding box from a label image,
    with an optional padding radius.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: Dimension of the input image.
        input_image: The input image from which a region will be extracted.
        output_image: The output image containing the extracted region.
        label_mask_image: The label mask image used to extract the bounding\
            box.
        label: The label value used to extract the sub-region.
        pad_radius: Optional padding radius to be added around the bounding\
            box.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ExtractRegionFromImageByMaskOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(EXTRACT_REGION_FROM_IMAGE_BY_MASK_METADATA)
    cargs = []
    cargs.append("ExtractRegionFromImageByMask")
    cargs.append(str(image_dimension))
    cargs.append(execution.input_file(input_image))
    cargs.append(execution.input_file(output_image))
    cargs.append(execution.input_file(label_mask_image))
    if label is not None:
        cargs.append(str(label))
    if pad_radius is not None:
        cargs.append(str(pad_radius))
    ret = ExtractRegionFromImageByMaskOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "EXTRACT_REGION_FROM_IMAGE_BY_MASK_METADATA",
    "ExtractRegionFromImageByMaskOutputs",
    "extract_region_from_image_by_mask",
]
